# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: onexfabricapi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13onexfabricapi.proto\x12\ronexfabricapi\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"$\n\rOpenApiMsgOpt\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"5\n\rOpenApiFldOpt\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\n \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x14 \x01(\t\"$\n\rOpenApiSvcOpt\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"$\n\rOpenApiRpcOpt\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"|\n\x11GlobalNamedObject\x12\x39\n\x04name\x18\x01 \x01(\tB&\x92\xa6\x1d\"\xa2\x01\x1fUnique identifier for an objectH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_name\"\x83\x01\n\x0c\x45rrorDetails\x12N\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x18.onexfabricapi.ErrorItemB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\x87\x01\n\x0eWarningDetails\x12P\n\x08warnings\x18\x01 \x03(\x0b\x32\x18.onexfabricapi.ErrorItemB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\x80\x02\n\tErrorItem\x12:\n\x07message\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x37\n\x04\x63ode\x18\x02 \x01(\x05\x42$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12\x39\n\x06\x64\x65tail\x18\x03 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\n\n\x08_messageB\x07\n\x05_codeB\t\n\x07_detail\"\xf8\x03\n\x06\x43onfig\x12H\n\x05hosts\x18\x01 \x03(\x0b\x32\x13.onexfabricapi.HostB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12P\n\x06\x66\x61\x62ric\x18\x02 \x01(\x0b\x32\x15.onexfabricapi.FabricB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x65\n\x0flayer1_profiles\x18\x03 \x03(\x0b\x32 .onexfabricapi.L1SettingsProfileB*\x92\xa6\x1d&\xa2\x01#A list of Layer 1 settings profiles\x12N\n\x05\x63haos\x18\x04 \x01(\x0b\x32\x14.onexfabricapi.ChaosB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12T\n\x08insights\x18\x05 \x01(\x0b\x32\x17.onexfabricapi.InsightsB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\t\n\x07_fabricB\x08\n\x06_chaosB\x0b\n\t_insights\"\xd3\x03\n\x04Host\x12<\n\x04name\x18\x01 \x01(\tB.\x92\xa6\x1d*\xa2\x01\'The name, uniquely identifying the host\x12\x34\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB#\x92\xa6\x1d\x1f\xa2\x01\x1cThe test address of the host\x12:\n\x06prefix\x18\x03 \x01(\x05\x42%\x92\xa6\x1d\x04R\x02\x32\x34\x92\xa6\x1d\x19\xa2\x01\x16The prefix of the hostH\x00\x88\x01\x01\x12\xd6\x01\n\x0fl1_profile_name\x18\x04 \x01(\tB\xb7\x01\x92\xa6\x1d\xb2\x01\xa2\x01\xae\x01The layer 1 settings profile associated with the host/front panel port.\n\nx-constraint:\n- ../l1settings/l1_profiles.yaml#/components/schemas/L1SettingsProfile/properties/name\nH\x01\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\t\n\x07_prefixB\x12\n\x10_l1_profile_name\"\x8b\x03\n\x06\x46\x61\x62ric\x12\\\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.onexfabricapi.Fabric.Choice.EnumB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12R\n\x04\x63los\x18\x02 \x01(\x0b\x32\x19.onexfabricapi.FabricClosB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12i\n\x0cqos_profiles\x18\x03 \x03(\x0b\x32\x1f.onexfabricapi.FabricQosProfileB2\x92\xa6\x1d.\xa2\x01+A list of Quality of Service (QoS) profiles\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x63los\x10\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\t\n\x07_choiceB\x07\n\x05_clos\"\x91\x06\n\nFabricClos\x12T\n\x05spine\x18\x01 \x01(\x0b\x32\x1a.onexfabricapi.FabricSpineB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12H\n\x04pods\x18\x02 \x03(\x0b\x32\x18.onexfabricapi.FabricPodB \x92\xa6\x1d\x1c\xa2\x01\x19The pods in the topology.\x12W\n\nhost_links\x18\x03 \x03(\x0b\x32\x1d.onexfabricapi.SwitchHostLinkB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12T\n\x0cpod_profiles\x18\x04 \x03(\x0b\x32\x1f.onexfabricapi.FabricPodProfileB\x1d\x92\xa6\x1d\x19\xa2\x01\x16\x41 list of pod profiles\x12[\n\x0ctor_profiles\x18\x05 \x03(\x0b\x32\x1f.onexfabricapi.FabricTorProfileB$\x92\xa6\x1d \xa2\x01\x1d\x41 list of ToR switch profiles\x12\x9a\x01\n\x15parallel_fabric_count\x18\x06 \x01(\x05\x42v\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1dk\xa2\x01hNumber of parallel fabrics (aka fabric colors). Spine and pod switches \nare fully meshed within a fabricH\x01\x88\x01\x01:\x95\x01\x8a\xa6\x1d\x90\x01R\x8d\x01\x41n emulation of a multistage switch topology. When folded, results in a topology with (up to) 3 tiers identified as \nspine, pod and tor tier.B\x08\n\x06_spineB\x18\n\x16_parallel_fabric_count\"\xe6\x06\n\x0b\x46\x61\x62ricSpine\x12\x9a\x01\n\x05\x63ount\x18\x01 \x01(\x05\x42\x85\x01\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1dz\xa2\x01wThe number of spines to be created with each spine sharing the same\ndownlink_ecmp_mode and qos_profile_name properties.H\x00\x88\x01\x01\x12\xe1\x02\n\x12\x64ownlink_ecmp_mode\x18\x02 \x01(\x0e\x32\x30.onexfabricapi.FabricSpine.DownlinkEcmpMode.EnumB\x8d\x02\x92\xa6\x1d\x88\x02\xa2\x01\x84\x02The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash modeH\x01\x88\x01\x01\x12\x97\x01\n\x10qos_profile_name\x18\x03 \x01(\tBx\x92\xa6\x1dt\xa2\x01qThe name of a qos profile shared by the spines.\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\nH\x02\x88\x01\x01\x1a\x61\n\x10\x44ownlinkEcmpMode\"M\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crandom_spray\x10\x01\x12\x10\n\x0chash_3_tuple\x10\x02\x12\x10\n\x0chash_5_tuple\x10\x03:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_countB\x15\n\x13_downlink_ecmp_modeB\x13\n\x11_qos_profile_name\"\xbc\x02\n\tFabricPod\x12U\n\x05\x63ount\x18\x01 \x01(\x05\x42\x41\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d\x36\xa2\x01\x33The number of pods that will share the same profileH\x00\x88\x01\x01\x12\x93\x01\n\x10pod_profile_name\x18\x02 \x01(\tBt\x92\xa6\x1dp\xa2\x01mThe pod profile associated with the pod(s).\n\nx-constraint:\n- #/components/schemas/PodProfile/properties/name\nH\x01\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_countB\x13\n\x11_pod_profile_name\"\xb0\x03\n\x10\x46\x61\x62ricPodProfile\x12;\n\x04name\x18\x01 \x01(\tB(\x92\xa6\x1d$\xa2\x01!Uniquely identifies a pod profileH\x00\x88\x01\x01\x12]\n\npod_switch\x18\x02 \x01(\x0b\x32\x1e.onexfabricapi.FabricPodSwitchB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12\x42\n\x04tors\x18\x03 \x03(\x0b\x32\x18.onexfabricapi.FabricTorB\x1a\x92\xa6\x1d\x16\xa2\x01\x13The ToRs in the pod\x12]\n\x1dpod_to_spine_oversubscription\x18\x04 \x01(\tB1\x92\xa6\x1d-\xa2\x01*Oversubscription ratio of the pod switchesH\x02\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_nameB\r\n\x0b_pod_switchB \n\x1e_pod_to_spine_oversubscription\"\x83\n\n\x0f\x46\x61\x62ricPodSwitch\x12?\n\x05\x63ount\x18\x01 \x01(\x05\x42+\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\xe1\x02\n\x10uplink_ecmp_mode\x18\x02 \x01(\x0e\x32\x32.onexfabricapi.FabricPodSwitch.UplinkEcmpMode.EnumB\x8d\x02\x92\xa6\x1d\x88\x02\xa2\x01\x84\x02The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash modeH\x01\x88\x01\x01\x12\xe5\x02\n\x12\x64ownlink_ecmp_mode\x18\x03 \x01(\x0e\x32\x34.onexfabricapi.FabricPodSwitch.DownlinkEcmpMode.EnumB\x8d\x02\x92\xa6\x1d\x88\x02\xa2\x01\x84\x02The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash modeH\x02\x88\x01\x01\x12\xae\x01\n\x10qos_profile_name\x18\x04 \x01(\tB\x8e\x01\x92\xa6\x1d\x89\x01\xa2\x01\x85\x01The name of a qos profile associated with the switches in this pod.\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\nH\x03\x88\x01\x01\x1a_\n\x0eUplinkEcmpMode\"M\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crandom_spray\x10\x01\x12\x10\n\x0chash_3_tuple\x10\x02\x12\x10\n\x0chash_5_tuple\x10\x03\x1a\x61\n\x10\x44ownlinkEcmpMode\"M\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crandom_spray\x10\x01\x12\x10\n\x0chash_3_tuple\x10\x02\x12\x10\n\x0chash_5_tuple\x10\x03:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_countB\x13\n\x11_uplink_ecmp_modeB\x15\n\x13_downlink_ecmp_modeB\x13\n\x11_qos_profile_name\"\xd3\x02\n\tFabricTor\x12Y\n\x05\x63ount\x18\x01 \x01(\x05\x42\x45\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d:\xa2\x01\x37number of ToR switches that will share the same profileH\x00\x88\x01\x01\x12\xa6\x01\n\x10tor_profile_name\x18\x02 \x01(\tB\x86\x01\x92\xa6\x1d\x81\x01\xa2\x01~The names of ToR profiles associated with the ToR switch(es)\n\nx-constraint:\n- #/components/schemas/TorProfile/properties/name\nH\x01\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_countB\x13\n\x11_tor_profile_name\"\xd9\x08\n\x10\x46\x61\x62ricTorProfile\x12\x37\n\x04name\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12[\n\x08tor_mode\x18\x02 \x01(\x0e\x32,.onexfabricapi.FabricTorProfile.TorMode.EnumB\x16\x92\xa6\x1d\x12\xa2\x01\x0fToR switch modeH\x01\x88\x01\x01\x12\xe2\x02\n\x10uplink_ecmp_mode\x18\x03 \x01(\x0e\x32\x33.onexfabricapi.FabricTorProfile.UplinkEcmpMode.EnumB\x8d\x02\x92\xa6\x1d\x88\x02\xa2\x01\x84\x02The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash modeH\x02\x88\x01\x01\x12\xa6\x01\n\x10qos_profile_name\x18\x04 \x01(\tB\x86\x01\x92\xa6\x1d\x81\x01\xa2\x01~The name of a qos profile associated with the ToR switch(es)\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\nH\x03\x88\x01\x01\x12\x7f\n\x1btor_to_pod_oversubscription\x18\x05 \x01(\x0b\x32/.onexfabricapi.FabricTorProfileOversubscriptionB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x04\x88\x01\x01\x1a:\n\x07TorMode\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06layer2\x10\x01\x12\n\n\x06layer3\x10\x02\x1a_\n\x0eUplinkEcmpMode\"M\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0crandom_spray\x10\x01\x12\x10\n\x0chash_3_tuple\x10\x02\x12\x10\n\x0chash_5_tuple\x10\x03:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_nameB\x0b\n\t_tor_modeB\x13\n\x11_uplink_ecmp_modeB\x13\n\x11_qos_profile_nameB\x1e\n\x1c_tor_to_pod_oversubscription\"\xe5\x03\n FabricTorProfileOversubscription\x12\x38\n\x05ratio\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x93\x01\n\x04mode\x18\x02 \x01(\x0e\x32\x39.onexfabricapi.FabricTorProfileOversubscription.Mode.EnumBE\x92\xa6\x1d\x1dR\x1bMode.Enum.use_host_capacity\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12G\n\rhost_capacity\x18\x03 \x01(\x05\x42+\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x1aQ\n\x04Mode\"I\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x15\n\x11use_host_capacity\x10\x01\x12\x19\n\x15use_fabric_host_links\x10\x02:0\x8a\xa6\x1d,R*The oversubscription of the ToR switch(es)B\x08\n\x06_ratioB\x07\n\x05_modeB\x10\n\x0e_host_capacity\"\xee\x04\n\x10\x46\x61\x62ricQosProfile\x12\x32\n\x04name\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12u\n\x11ingress_admission\x18\x02 \x01(\x0b\x32/.onexfabricapi.FabricQosProfileIngressAdmissionB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x66\n\tscheduler\x18\x03 \x01(\x0b\x32(.onexfabricapi.FabricQosProfileSchedulerB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12}\n\x15packet_classification\x18\x04 \x01(\x0b\x32\x33.onexfabricapi.FabricQosProfilePacketClassificationB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x12\\\n\x04wred\x18\x05 \x01(\x0b\x32#.onexfabricapi.FabricQosProfileWredB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x03\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x14\n\x12_ingress_admissionB\x0c\n\n_schedulerB\x18\n\x16_packet_classificationB\x07\n\x05_wred\"\xc0\x03\n FabricQosProfileIngressAdmission\x12\x81\x01\n\x15reserved_buffer_bytes\x18\x01 \x01(\x05\x42]\x92\xa6\x1d\x03R\x01\x30\x92\xa6\x1dR\xa2\x01OBuffer space (in bytes) reserved for each port that this Qos profile applies toH\x00\x88\x01\x01\x12\x62\n\x13shared_buffer_bytes\x18\x02 \x01(\x05\x42@\x92\xa6\x1d\x03R\x01\x30\x92\xa6\x1d\x35\xa2\x01\x32\x41mount of shared buffer space (in bytes) availableH\x01\x88\x01\x01\x12]\n\rpriority_list\x18\x03 \x03(\tBF\x92\xa6\x1d\x42\xa2\x01?List of priorities for which the buffer sizes should be applied:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x18\n\x16_reserved_buffer_bytesB\x16\n\x14_shared_buffer_bytes\"\x94\x03\n\x19\x46\x61\x62ricQosProfileScheduler\x12\x81\x01\n\x0escheduler_mode\x18\x01 \x01(\x0e\x32;.onexfabricapi.FabricQosProfileScheduler.SchedulerMode.EnumB\'\x92\xa6\x1d#\xa2\x01 The queue scheduling discipline H\x00\x88\x01\x01\x12\x62\n\x0bweight_list\x18\x02 \x03(\x05\x42M\x92\xa6\x1dI\xa2\x01\x46\x41 list of egress queue weights for weighted round robin scheduler mode\x1aW\n\rSchedulerMode\"F\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0fstrict_priority\x10\x01\x12\x18\n\x14weighted_round_robin\x10\x02:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x11\n\x0f_scheduler_mode\"\x97\x03\n$FabricQosProfilePacketClassification\x12\x84\x01\n\x19map_dscp_to_traffic_class\x18\x01 \x01(\x0b\x32\x36.onexfabricapi.FabricQosProfilePacketClassificationMapB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x85\x01\n\x1amap_traffic_class_to_queue\x18\x02 \x01(\x0b\x32\x36.onexfabricapi.FabricQosProfilePacketClassificationMapB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x1c\n\x1a_map_dscp_to_traffic_classB\x1d\n\x1b_map_traffic_class_to_queue\"N\n\'FabricQosProfilePacketClassificationMap:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\xac\x05\n\x14\x46\x61\x62ricQosProfileWred\x12\x43\n\nqueue_list\x18\x01 \x03(\tB/\x92\xa6\x1d+\xa2\x01(List of queues for which WRED is enabled\x12Q\n\x13\x65\x63n_marking_enabled\x18\x02 \x01(\x08\x42/\x92\xa6\x1d\x07R\x05\x46\x61lse\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12u\n\x13min_threshold_bytes\x18\x03 \x01(\x05\x42S\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1dH\xa2\x01\x45\x45gress queue threshold beyond which packets will be droppes or markedH\x01\x88\x01\x01\x12u\n\x13max_threshold_bytes\x18\x04 \x01(\x05\x42S\x92\xa6\x1d\x03R\x01\x32\x92\xa6\x1dH\xa2\x01\x45\x45gress queue threshold beyond which packets will be droppes or markedH\x02\x88\x01\x01\x12n\n\x17max_probability_percent\x18\x05 \x01(\x05\x42H\x92\xa6\x1d\x05R\x03\x31\x30\x30\x92\xa6\x1d;\xa2\x01\x38Probability of dropping/marking packets at max thresholdH\x03\x88\x01\x01::\x8a\xa6\x1d\x36R4WRED (weighted random early detection) configurationB\x16\n\x14_ecn_marking_enabledB\x16\n\x14_min_threshold_bytesB\x16\n\x14_max_threshold_bytesB\x1a\n\x18_max_probability_percent\"\xca\n\n\x0eSwitchHostLink\x12X\n\thost_name\x18\x01 \x01(\tBE\x92\xa6\x1d\x41\xa2\x01>TBD\n\nx-constraint:\n- #components/schemas/Host/properties/name\n\x12\x88\x03\n\thost_type\x18\x02 \x01(\x0e\x32+.onexfabricapi.SwitchHostLink.HostType.EnumB\xc2\x02\x92\xa6\x1d\x18R\x16HostType.Enum.external\x92\xa6\x1d\xa1\x02\xa2\x01\x9d\x02Optional host type, if fabric is rendered on physical box.\n- external for hosts/servers physically connected to front panel ports\n- internal_traffic_sink for an emulated server that acts as a traffic sink (i.e. packets sent to its IP address will be routed through the emulated fabric)H\x00\x88\x01\x01\x12m\n\x10\x66ront_panel_port\x18\x03 \x01(\x05\x42N\x92\xa6\x1dJ\xa2\x01GOptional front panel port number, if fabric is rendered on physical boxH\x01\x88\x01\x01\x12y\n\x06\x63hoice\x18\x04 \x01(\x0e\x32).onexfabricapi.SwitchHostLink.Choice.EnumB9\x92\xa6\x1d\x11R\x0f\x43hoice.Enum.tor\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x12~\n\x05spine\x18\x05 \x01(\x05\x42j\x92\xa6\x1d\x66\xa2\x01\x63One based index of the spine switch based on the number of spines \nconfigured in the clos topology.H\x03\x88\x01\x01\x12^\n\x03pod\x18\x06 \x01(\x0b\x32&.onexfabricapi.SwitchHostLinkSwitchRefB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x04\x88\x01\x01\x12^\n\x03tor\x18\x07 \x01(\x0b\x32&.onexfabricapi.SwitchHostLinkSwitchRefB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x05\x88\x01\x01\x1aL\n\x08HostType\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08\x65xternal\x10\x01\x12\x19\n\x15internal_traffic_sink\x10\x02\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05spine\x10\x01\x12\x07\n\x03pod\x10\x02\x12\x07\n\x03tor\x10\x03:S\x8a\xa6\x1dORMThe ingress point of a host which is the index of a spine, pod or tor switch.B\x0c\n\n_host_typeB\x13\n\x11_front_panel_portB\t\n\x07_choiceB\x08\n\x06_spineB\x06\n\x04_podB\x06\n\x04_tor\"\xc8\x02\n\x17SwitchHostLinkSwitchRef\x12j\n\tpod_index\x18\x01 \x01(\x05\x42R\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1dG\xa2\x01\x44One-based index of the pod based on the number of pods in the fabricH\x00\x88\x01\x01\x12\x66\n\x0cswitch_index\x18\x02 \x01(\x05\x42K\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d@\xa2\x01=One-based index of the pod or ToR switch in the indicated podH\x01\x88\x01\x01::\x8a\xa6\x1d\x36R4Location of the switch based on pod and switch indexB\x0c\n\n_pod_indexB\x0f\n\r_switch_index\"\xcc\x06\n\x11L1SettingsProfile\x12H\n\x04name\x18\x01 \x01(\tB5\x92\xa6\x1d\x31\xa2\x01.Uniquely identifies a layer 1 settings profileH\x00\x88\x01\x01\x12~\n\nlink_speed\x18\x02 \x01(\x0e\x32/.onexfabricapi.L1SettingsProfile.LinkSpeed.EnumB4\x92\xa6\x1d\x1fR\x1dLinkSpeed.Enum.speed_100_gbps\x92\xa6\x1d\r\xa2\x01\nLink speedH\x01\x88\x01\x01\x12\x88\x01\n\x06\x63hoice\x18\x03 \x01(\x0e\x32,.onexfabricapi.L1SettingsProfile.Choice.EnumBE\x92\xa6\x1d\x1dR\x1b\x43hoice.Enum.autonegotiation\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x12s\n\x0f\x61utonegotiation\x18\x04 \x01(\x0b\x32/.onexfabricapi.L1SettingsProfileAutonegotiationB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x03\x88\x01\x01\x12\x61\n\x06manual\x18\x05 \x01(\x0b\x32&.onexfabricapi.L1SettingsProfileManualB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x04\x88\x01\x01\x1a_\n\tLinkSpeed\"R\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0espeed_100_gbps\x10\x01\x12\x12\n\x0espeed_200_gbps\x10\x02\x12\x11\n\rspeed_50_gbps\x10\x03\x1a\x42\n\x06\x43hoice\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0f\x61utonegotiation\x10\x01\x12\n\n\x06manual\x10\x02:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_nameB\r\n\x0b_link_speedB\t\n\x07_choiceB\x12\n\x10_autonegotiationB\t\n\x07_manual\"\xa5\x01\n L1SettingsProfileAutonegotiation\x12J\n\radvertise_fec\x18\x01 \x01(\x08\x42.\x92\xa6\x1d\x06R\x04True\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x10\n\x0e_advertise_fec\"\xaa\x02\n\x17L1SettingsProfileManual\x12\x8f\x01\n\x08\x66\x65\x63_mode\x18\x01 \x01(\x0e\x32\x33.onexfabricapi.L1SettingsProfileManual.FecMode.EnumBC\x92\xa6\x1d\x1bR\x19\x46\x65\x63Mode.Enum.reed_solomon\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x1aK\n\x07\x46\x65\x63Mode\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0creed_solomon\x10\x01\x12\x0c\n\x08\x66irecode\x10\x02\x12\x07\n\x03kp4\x10\x03:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x0b\n\t_fec_mode\"\x91\x02\n\x05\x43haos\x12l\n\x12\x62\x61\x63kground_traffic\x18\x01 \x01(\x0b\x32%.onexfabricapi.ChaosBackgroundTrafficB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12Y\n\x0b\x64rop_frames\x18\x02 \x03(\x0b\x32\x1e.onexfabricapi.ChaosDropFramesB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:(\x8a\xa6\x1d$R\"Configuration of chaos experimentsB\x15\n\x13_background_traffic\"\xed\x05\n\x0f\x43haosDropFrames\x12\x43\n\x04name\x18\x01 \x01(\tB5\x92\xa6\x1d\x31\xa2\x01.Uniquely identifies a drop frames config entry\x12\x38\n\x04link\x18\x02 \x01(\tB*\x92\xa6\x1d&\xa2\x01#Emulated link name, e.g. Link S.1/2\x12\xeb\x01\n\x04mode\x18\x03 \x01(\x0e\x32(.onexfabricapi.ChaosDropFrames.Mode.EnumB\xad\x01\x92\xa6\x1d\x1bR\x19Mode.Enum.percentage_time\x92\xa6\x1d\x89\x01\xa2\x01\x85\x01Mode to express the duration in which frames are dropped, either a percentage of the specified time interval or the min possible timeH\x00\x88\x01\x01\x12T\n\npercentage\x18\x04 \x01(\x02\x42;\x92\xa6\x1d\x03R\x01\x35\x92\xa6\x1d\x30\xa2\x01-Percentage value, ignored if type is min_timeH\x01\x88\x01\x01\x12?\n\x08interval\x18\x05 \x01(\x05\x42(\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d\x1d\xa2\x01\x1aInterval of time (seconds)H\x02\x88\x01\x01\x1a\x42\n\x04Mode\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0fpercentage_time\x10\x01\x12\x0c\n\x08min_time\x10\x02:m\x8a\xa6\x1diRgConfigures an emulated link to periodically drop frames for a percentage of the specified time intervalB\x07\n\x05_modeB\r\n\x0b_percentageB\x0b\n\t_interval\"\x9d\x01\n\x16\x43haosBackgroundTraffic\x12^\n\x05\x66lows\x18\x01 \x03(\x0b\x32).onexfabricapi.ChaosBackgroundTrafficFlowB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\x99\x04\n\x1a\x43haosBackgroundTrafficFlow\x12\x37\n\x04name\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12R\n\x0einjection_port\x18\x02 \x01(\tB5\x92\xa6\x1d\x31\xa2\x01.Emulated port name, e.g. Spine Switch 1 Port 1H\x01\x88\x01\x01\x12p\n\x06\x63hoice\x18\x03 \x01(\x0e\x32\x35.onexfabricapi.ChaosBackgroundTrafficFlow.Choice.EnumB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x12p\n\tstateless\x18\x04 \x01(\x0b\x32\x32.onexfabricapi.ChaosBackgroundTrafficFlowStatelessB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x03\x88\x01\x01\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tstateless\x10\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_nameB\x11\n\x0f_injection_portB\t\n\x07_choiceB\x0c\n\n_stateless\"\xc8\x05\n#ChaosBackgroundTrafficFlowStateless\x12\x61\n\x04rate\x18\x01 \x01(\x05\x42N\x92\xa6\x1dJ\xa2\x01GTransmission rate specified as a percentage of the injection port speedH\x00\x88\x01\x01\x12\xb4\x01\n\x11transmission_mode\x18\x02 \x01(\x0e\x32H.onexfabricapi.ChaosBackgroundTrafficFlowStateless.TransmissionMode.EnumBJ\x92\xa6\x1d\"R TransmissionMode.Enum.continuous\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12s\n\x06packet\x18\x03 \x01(\x0b\x32\x38.onexfabricapi.ChaosBackgroundTrafficFlowStatelessPacketB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x12q\n\x05\x62urst\x18\x04 \x01(\x0b\x32\x37.onexfabricapi.ChaosBackgroundTrafficFlowStatelessBurstB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x03\x88\x01\x01\x1a\x46\n\x10TransmissionMode\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\ncontinuous\x10\x01\x12\t\n\x05\x62urst\x10\x02:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_rateB\x14\n\x12_transmission_modeB\t\n\x07_packetB\x08\n\x06_burst\"\x92\x06\n)ChaosBackgroundTrafficFlowStatelessPacket\x12\x32\n\x0bsrc_address\x18\x01 \x01(\tB\x18\x92\xa6\x1d\x14\xa2\x01\x11source IP addressH\x00\x88\x01\x01\x12\x37\n\x0b\x64st_address\x18\x02 \x01(\tB\x1d\x92\xa6\x1d\x19\xa2\x01\x16\x64\x65stination IP addressH\x01\x88\x01\x01\x12;\n\x08src_port\x18\x03 \x01(\x05\x42$\x92\xa6\x1d\x06R\x04\x31\x30\x32\x34\x92\xa6\x1d\x16\xa2\x01\x13Layer 4 source portH\x02\x88\x01\x01\x12@\n\x08\x64st_port\x18\x04 \x01(\x05\x42)\x92\xa6\x1d\x06R\x04\x31\x30\x32\x34\x92\xa6\x1d\x1b\xa2\x01\x18Layer 4 destination portH\x03\x88\x01\x01\x12\x35\n\x04size\x18\x05 \x01(\x05\x42\"\x92\xa6\x1d\x06R\x04\x31\x30\x30\x30\x92\xa6\x1d\x14\xa2\x01\x11total packet sizeH\x04\x88\x01\x01\x12\x85\x01\n\x0bl4_protocol\x18\x06 \x01(\x0e\x32H.onexfabricapi.ChaosBackgroundTrafficFlowStatelessPacket.L4Protocol.EnumB!\x92\xa6\x1d\x1d\xa2\x01\x1aLayer 4 transport protocolH\x05\x88\x01\x01\x12|\n\x08\x64s_field\x18\x07 \x01(\x0b\x32?.onexfabricapi.ChaosBackgroundTrafficFlowStatelessPacketDsFieldB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x06\x88\x01\x01\x1a\x37\n\nL4Protocol\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03tcp\x10\x01\x12\x07\n\x03udp\x10\x02:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x0e\n\x0c_src_addressB\x0e\n\x0c_dst_addressB\x0b\n\t_src_portB\x0b\n\t_dst_portB\x07\n\x05_sizeB\x0e\n\x0c_l4_protocolB\x0b\n\t_ds_field\"\x8a\x02\n0ChaosBackgroundTrafficFlowStatelessPacketDsField\x12G\n\x04\x64scp\x18\x01 \x01(\x05\x42\x34\x92\xa6\x1d\x03R\x01\x30\x92\xa6\x1d)\xa2\x01&Differentiated Service CodePoint filedH\x00\x88\x01\x01\x12\x46\n\x03\x65\x63n\x18\x02 \x01(\x05\x42\x34\x92\xa6\x1d\x03R\x01\x30\x92\xa6\x1d)\xa2\x01&Explicit Congestion Notification fieldH\x01\x88\x01\x01:4\x8a\xa6\x1d\x30R.Differentiated Services or Traffic Class fieldB\x07\n\x05_dscpB\x06\n\x04_ecn\"\xbe\x03\n(ChaosBackgroundTrafficFlowStatelessBurst\x12\x44\n\x11transmit_duration\x18\x01 \x01(\x05\x42$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12?\n\x0ctransmit_gap\x18\x02 \x01(\x05\x42$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12\x8c\x01\n\x04unit\x18\x03 \x01(\x0e\x32\x41.onexfabricapi.ChaosBackgroundTrafficFlowStatelessBurst.Unit.EnumB6\x92\xa6\x1d\x0eR\x0cUnit.Enum.ms\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x1a\'\n\x04Unit\"\x1f\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02ms\x10\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x14\n\x12_transmit_durationB\x0f\n\r_transmit_gapB\x07\n\x05_unit\"\xa1\x01\n\x08Insights\x12\x62\n\x0eport_mirroring\x18\x01 \x03(\x0b\x32$.onexfabricapi.InsightsPortMirroringB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:1\x8a\xa6\x1d-R+Configuration of insights providing methods\"\xc0\x04\n\x15InsightsPortMirroring\x12\x44\n\x04name\x18\x01 \x01(\tB6\x92\xa6\x1d\x32\xa2\x01/Uniquely identifies a port port_mirroring entry\x12Y\n\x0bsource_port\x18\x02 \x01(\tBD\x92\xa6\x1d@\xa2\x01=Emulated port name, e.g. Spine Switch 1 Port 1 to be mirrored\x12h\n\x10\x64\x65stination_port\x18\x03 \x01(\x05\x42N\x92\xa6\x1dJ\xa2\x01GFront panel port number of an external host, e.g. 32 on which to mirror\x12\x98\x01\n\x0bmirror_type\x18\x04 \x01(\x0e\x32\x34.onexfabricapi.InsightsPortMirroring.MirrorType.EnumBH\x92\xa6\x1d R\x1eMirrorType.Enum.ingress_frames\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x1aL\n\nMirrorType\">\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eingress_frames\x10\x01\x12\x11\n\regress_frames\x10\x02:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x0e\n\x0c_mirror_type\"\x99\x01\n\x0cStateRequest\x12Z\n\x05\x63haos\x18\x01 \x01(\x0b\x32 .onexfabricapi.StateRequestChaosB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_chaos\"\xc5\x02\n\x11StateRequestChaos\x12j\n\x0b\x64rop_frames\x18\x01 \x01(\x0b\x32*.onexfabricapi.StateRequestChaosDropFramesB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12x\n\x12\x62\x61\x63kground_traffic\x18\x02 \x01(\x0b\x32\x31.onexfabricapi.StateRequestChaosBackgroundTrafficB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x0e\n\x0c_drop_framesB\x15\n\x13_background_traffic\"\xa3\x04\n\"StateRequestChaosBackgroundTraffic\x12\x99\x02\n\nflow_names\x18\x01 \x03(\tB\x84\x02\x92\xa6\x1d\xff\x01\xa2\x01\xfb\x01The names of flows to which the transmit state will be applied to. If the list of flow_names is empty or null the state will be applied to all configured flows.\n\nx-constraint:\n- ../chaos/background_traffic.yaml/components/schemas/Flow/properties/name\n\x12v\n\x05state\x18\x02 \x01(\x0e\x32<.onexfabricapi.StateRequestChaosBackgroundTraffic.State.EnumB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x1a:\n\x05State\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_state\"\x96\x04\n\x1bStateRequestChaosDropFrames\x12\x9a\x02\n\x0c\x63onfig_names\x18\x01 \x03(\tB\x83\x02\x92\xa6\x1d\xfe\x01\xa2\x01\xfa\x01The names of the drop frams configs to which the transmit state will be applied to. If the list is empty or null the state will be applied to all drop frames entries.\n\nx-constraint:\n- ../chaos/chaos.yaml/components/schemas/DropFrames/properties/name\n\x12o\n\x05state\x18\x02 \x01(\x0e\x32\x35.onexfabricapi.StateRequestChaosDropFrames.State.EnumB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x1a:\n\x05State\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_state\"\x9b\x01\n\rStateResponse\x12[\n\x05\x63haos\x18\x01 \x01(\x0b\x32!.onexfabricapi.StateResponseChaosB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_chaos\"\xc8\x02\n\x12StateResponseChaos\x12k\n\x0b\x64rop_frames\x18\x01 \x01(\x0b\x32+.onexfabricapi.StateResponseChaosDropFramesB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12y\n\x12\x62\x61\x63kground_traffic\x18\x02 \x01(\x0b\x32\x32.onexfabricapi.StateResponseChaosBackgroundTrafficB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x0e\n\x0c_drop_framesB\x15\n\x13_background_traffic\"\xf6\x02\n#StateResponseChaosBackgroundTraffic\x12\x93\x01\n\x07started\x18\x01 \x03(\tB\x81\x01\x92\xa6\x1d}\xa2\x01zThe names of the started flows.\n\nx-constraint:\n- ../chaos/background_traffic.yaml/components/schemas/Flow/properties/name\n\x12\x93\x01\n\x07stopped\x18\x02 \x03(\tB\x81\x01\x92\xa6\x1d}\xa2\x01zThe names of the stopped flows.\n\nx-constraint:\n- ../chaos/background_traffic.yaml/components/schemas/Flow/properties/name\n:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\x89\x03\n\x1cStateResponseChaosDropFrames\x12\xa0\x01\n\x07started\x18\x01 \x03(\tB\x8e\x01\x92\xa6\x1d\x89\x01\xa2\x01\x85\x01The names of the started drop frames experiments.\n\nx-constraint:\n- ../chaos/chaos.yaml/components/schemas/DropFrames/properties/name\n\x12\xa0\x01\n\x07stopped\x18\x02 \x03(\tB\x8e\x01\x92\xa6\x1d\x89\x01\xa2\x01\x85\x01The names of the stopped drop frames experiments.\n\nx-constraint:\n- ../chaos/chaos.yaml/components/schemas/DropFrames/properties/name\n:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"9\n\x10SetConfigRequest\x12%\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x15.onexfabricapi.Config\"\x82\x02\n\x11SetConfigResponse\x12\x39\n\x0fstatus_code_400\x18\x01 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x00\x88\x01\x01\x12\x39\n\x0fstatus_code_500\x18\x02 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x01\x88\x01\x01\x12;\n\x0fstatus_code_200\x18\x03 \x01(\x0b\x32\x1d.onexfabricapi.WarningDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_400B\x12\n\x10_status_code_500B\x12\n\x10_status_code_200\"\xfa\x01\n\x11GetConfigResponse\x12\x33\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x15.onexfabricapi.ConfigH\x00\x88\x01\x01\x12\x39\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x01\x88\x01\x01\x12\x39\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"E\n\x0fSetStateRequest\x12\x32\n\rstate_request\x18\x01 \x01(\x0b\x32\x1b.onexfabricapi.StateRequest\"\x81\x02\n\x10SetStateResponse\x12\x39\n\x0fstatus_code_400\x18\x01 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x00\x88\x01\x01\x12\x39\n\x0fstatus_code_500\x18\x02 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x01\x88\x01\x01\x12;\n\x0fstatus_code_200\x18\x03 \x01(\x0b\x32\x1d.onexfabricapi.WarningDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_400B\x12\n\x10_status_code_500B\x12\n\x10_status_code_200\"\x80\x02\n\x10GetStateResponse\x12:\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x1c.onexfabricapi.StateResponseH\x00\x88\x01\x01\x12\x39\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x01\x88\x01\x01\x12\x39\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x1b.onexfabricapi.ErrorDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_5002\x9f\x04\n\x07Openapi\x12y\n\tSetConfig\x12\x1f.onexfabricapi.SetConfigRequest\x1a .onexfabricapi.SetConfigResponse\")\xa2\xa6\x1d%R#Sets the ONEx fabric configuration.\x12p\n\tGetConfig\x12\x16.google.protobuf.Empty\x1a .onexfabricapi.GetConfigResponse\")\xa2\xa6\x1d%R#Gets the ONEx fabric configuration.\x12\x86\x01\n\x08SetState\x12\x1e.onexfabricapi.SetStateRequest\x1a\x1f.onexfabricapi.SetStateResponse\"9\xa2\xa6\x1d\x35R3Updates the state of ONEx configured experiment(s).\x12y\n\x08GetState\x12\x16.google.protobuf.Empty\x1a\x1f.onexfabricapi.GetStateResponse\"4\xa2\xa6\x1d\x30R.Gets the state of ONEx configured experiments.\x1a#\x9a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models:T\n\x08msg_meta\x12\x1f.google.protobuf.MessageOptions\x18\xe1\xd4\x03 \x01(\x0b\x32\x1c.onexfabricapi.OpenApiMsgOpt\x88\x01\x01:R\n\x08\x66ld_meta\x12\x1d.google.protobuf.FieldOptions\x18\xe2\xd4\x03 \x01(\x0b\x32\x1c.onexfabricapi.OpenApiFldOpt\x88\x01\x01:T\n\x08svc_meta\x12\x1f.google.protobuf.ServiceOptions\x18\xe3\xd4\x03 \x01(\x0b\x32\x1c.onexfabricapi.OpenApiSvcOpt\x88\x01\x01:S\n\x08rpc_meta\x12\x1e.google.protobuf.MethodOptions\x18\xe4\xd4\x03 \x01(\x0b\x32\x1c.onexfabricapi.OpenApiRpcOpt\x88\x01\x01\x62\x06proto3')


MSG_META_FIELD_NUMBER = 60001
msg_meta = DESCRIPTOR.extensions_by_name['msg_meta']
FLD_META_FIELD_NUMBER = 60002
fld_meta = DESCRIPTOR.extensions_by_name['fld_meta']
SVC_META_FIELD_NUMBER = 60003
svc_meta = DESCRIPTOR.extensions_by_name['svc_meta']
RPC_META_FIELD_NUMBER = 60004
rpc_meta = DESCRIPTOR.extensions_by_name['rpc_meta']

_OPENAPIMSGOPT = DESCRIPTOR.message_types_by_name['OpenApiMsgOpt']
_OPENAPIFLDOPT = DESCRIPTOR.message_types_by_name['OpenApiFldOpt']
_OPENAPISVCOPT = DESCRIPTOR.message_types_by_name['OpenApiSvcOpt']
_OPENAPIRPCOPT = DESCRIPTOR.message_types_by_name['OpenApiRpcOpt']
_GLOBALNAMEDOBJECT = DESCRIPTOR.message_types_by_name['GlobalNamedObject']
_ERRORDETAILS = DESCRIPTOR.message_types_by_name['ErrorDetails']
_WARNINGDETAILS = DESCRIPTOR.message_types_by_name['WarningDetails']
_ERRORITEM = DESCRIPTOR.message_types_by_name['ErrorItem']
_CONFIG = DESCRIPTOR.message_types_by_name['Config']
_HOST = DESCRIPTOR.message_types_by_name['Host']
_FABRIC = DESCRIPTOR.message_types_by_name['Fabric']
_FABRIC_CHOICE = _FABRIC.nested_types_by_name['Choice']
_FABRICCLOS = DESCRIPTOR.message_types_by_name['FabricClos']
_FABRICSPINE = DESCRIPTOR.message_types_by_name['FabricSpine']
_FABRICSPINE_DOWNLINKECMPMODE = _FABRICSPINE.nested_types_by_name['DownlinkEcmpMode']
_FABRICPOD = DESCRIPTOR.message_types_by_name['FabricPod']
_FABRICPODPROFILE = DESCRIPTOR.message_types_by_name['FabricPodProfile']
_FABRICPODSWITCH = DESCRIPTOR.message_types_by_name['FabricPodSwitch']
_FABRICPODSWITCH_UPLINKECMPMODE = _FABRICPODSWITCH.nested_types_by_name['UplinkEcmpMode']
_FABRICPODSWITCH_DOWNLINKECMPMODE = _FABRICPODSWITCH.nested_types_by_name['DownlinkEcmpMode']
_FABRICTOR = DESCRIPTOR.message_types_by_name['FabricTor']
_FABRICTORPROFILE = DESCRIPTOR.message_types_by_name['FabricTorProfile']
_FABRICTORPROFILE_TORMODE = _FABRICTORPROFILE.nested_types_by_name['TorMode']
_FABRICTORPROFILE_UPLINKECMPMODE = _FABRICTORPROFILE.nested_types_by_name['UplinkEcmpMode']
_FABRICTORPROFILEOVERSUBSCRIPTION = DESCRIPTOR.message_types_by_name['FabricTorProfileOversubscription']
_FABRICTORPROFILEOVERSUBSCRIPTION_MODE = _FABRICTORPROFILEOVERSUBSCRIPTION.nested_types_by_name['Mode']
_FABRICQOSPROFILE = DESCRIPTOR.message_types_by_name['FabricQosProfile']
_FABRICQOSPROFILEINGRESSADMISSION = DESCRIPTOR.message_types_by_name['FabricQosProfileIngressAdmission']
_FABRICQOSPROFILESCHEDULER = DESCRIPTOR.message_types_by_name['FabricQosProfileScheduler']
_FABRICQOSPROFILESCHEDULER_SCHEDULERMODE = _FABRICQOSPROFILESCHEDULER.nested_types_by_name['SchedulerMode']
_FABRICQOSPROFILEPACKETCLASSIFICATION = DESCRIPTOR.message_types_by_name['FabricQosProfilePacketClassification']
_FABRICQOSPROFILEPACKETCLASSIFICATIONMAP = DESCRIPTOR.message_types_by_name['FabricQosProfilePacketClassificationMap']
_FABRICQOSPROFILEWRED = DESCRIPTOR.message_types_by_name['FabricQosProfileWred']
_SWITCHHOSTLINK = DESCRIPTOR.message_types_by_name['SwitchHostLink']
_SWITCHHOSTLINK_HOSTTYPE = _SWITCHHOSTLINK.nested_types_by_name['HostType']
_SWITCHHOSTLINK_CHOICE = _SWITCHHOSTLINK.nested_types_by_name['Choice']
_SWITCHHOSTLINKSWITCHREF = DESCRIPTOR.message_types_by_name['SwitchHostLinkSwitchRef']
_L1SETTINGSPROFILE = DESCRIPTOR.message_types_by_name['L1SettingsProfile']
_L1SETTINGSPROFILE_LINKSPEED = _L1SETTINGSPROFILE.nested_types_by_name['LinkSpeed']
_L1SETTINGSPROFILE_CHOICE = _L1SETTINGSPROFILE.nested_types_by_name['Choice']
_L1SETTINGSPROFILEAUTONEGOTIATION = DESCRIPTOR.message_types_by_name['L1SettingsProfileAutonegotiation']
_L1SETTINGSPROFILEMANUAL = DESCRIPTOR.message_types_by_name['L1SettingsProfileManual']
_L1SETTINGSPROFILEMANUAL_FECMODE = _L1SETTINGSPROFILEMANUAL.nested_types_by_name['FecMode']
_CHAOS = DESCRIPTOR.message_types_by_name['Chaos']
_CHAOSDROPFRAMES = DESCRIPTOR.message_types_by_name['ChaosDropFrames']
_CHAOSDROPFRAMES_MODE = _CHAOSDROPFRAMES.nested_types_by_name['Mode']
_CHAOSBACKGROUNDTRAFFIC = DESCRIPTOR.message_types_by_name['ChaosBackgroundTraffic']
_CHAOSBACKGROUNDTRAFFICFLOW = DESCRIPTOR.message_types_by_name['ChaosBackgroundTrafficFlow']
_CHAOSBACKGROUNDTRAFFICFLOW_CHOICE = _CHAOSBACKGROUNDTRAFFICFLOW.nested_types_by_name['Choice']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESS = DESCRIPTOR.message_types_by_name['ChaosBackgroundTrafficFlowStateless']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESS_TRANSMISSIONMODE = _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS.nested_types_by_name['TransmissionMode']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET = DESCRIPTOR.message_types_by_name['ChaosBackgroundTrafficFlowStatelessPacket']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET_L4PROTOCOL = _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.nested_types_by_name['L4Protocol']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD = DESCRIPTOR.message_types_by_name['ChaosBackgroundTrafficFlowStatelessPacketDsField']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST = DESCRIPTOR.message_types_by_name['ChaosBackgroundTrafficFlowStatelessBurst']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST_UNIT = _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST.nested_types_by_name['Unit']
_INSIGHTS = DESCRIPTOR.message_types_by_name['Insights']
_INSIGHTSPORTMIRRORING = DESCRIPTOR.message_types_by_name['InsightsPortMirroring']
_INSIGHTSPORTMIRRORING_MIRRORTYPE = _INSIGHTSPORTMIRRORING.nested_types_by_name['MirrorType']
_STATEREQUEST = DESCRIPTOR.message_types_by_name['StateRequest']
_STATEREQUESTCHAOS = DESCRIPTOR.message_types_by_name['StateRequestChaos']
_STATEREQUESTCHAOSBACKGROUNDTRAFFIC = DESCRIPTOR.message_types_by_name['StateRequestChaosBackgroundTraffic']
_STATEREQUESTCHAOSBACKGROUNDTRAFFIC_STATE = _STATEREQUESTCHAOSBACKGROUNDTRAFFIC.nested_types_by_name['State']
_STATEREQUESTCHAOSDROPFRAMES = DESCRIPTOR.message_types_by_name['StateRequestChaosDropFrames']
_STATEREQUESTCHAOSDROPFRAMES_STATE = _STATEREQUESTCHAOSDROPFRAMES.nested_types_by_name['State']
_STATERESPONSE = DESCRIPTOR.message_types_by_name['StateResponse']
_STATERESPONSECHAOS = DESCRIPTOR.message_types_by_name['StateResponseChaos']
_STATERESPONSECHAOSBACKGROUNDTRAFFIC = DESCRIPTOR.message_types_by_name['StateResponseChaosBackgroundTraffic']
_STATERESPONSECHAOSDROPFRAMES = DESCRIPTOR.message_types_by_name['StateResponseChaosDropFrames']
_SETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetConfigRequest']
_SETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['SetConfigResponse']
_GETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['GetConfigResponse']
_SETSTATEREQUEST = DESCRIPTOR.message_types_by_name['SetStateRequest']
_SETSTATERESPONSE = DESCRIPTOR.message_types_by_name['SetStateResponse']
_GETSTATERESPONSE = DESCRIPTOR.message_types_by_name['GetStateResponse']
_FABRIC_CHOICE_ENUM = _FABRIC_CHOICE.enum_types_by_name['Enum']
_FABRICSPINE_DOWNLINKECMPMODE_ENUM = _FABRICSPINE_DOWNLINKECMPMODE.enum_types_by_name['Enum']
_FABRICPODSWITCH_UPLINKECMPMODE_ENUM = _FABRICPODSWITCH_UPLINKECMPMODE.enum_types_by_name['Enum']
_FABRICPODSWITCH_DOWNLINKECMPMODE_ENUM = _FABRICPODSWITCH_DOWNLINKECMPMODE.enum_types_by_name['Enum']
_FABRICTORPROFILE_TORMODE_ENUM = _FABRICTORPROFILE_TORMODE.enum_types_by_name['Enum']
_FABRICTORPROFILE_UPLINKECMPMODE_ENUM = _FABRICTORPROFILE_UPLINKECMPMODE.enum_types_by_name['Enum']
_FABRICTORPROFILEOVERSUBSCRIPTION_MODE_ENUM = _FABRICTORPROFILEOVERSUBSCRIPTION_MODE.enum_types_by_name['Enum']
_FABRICQOSPROFILESCHEDULER_SCHEDULERMODE_ENUM = _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE.enum_types_by_name['Enum']
_SWITCHHOSTLINK_HOSTTYPE_ENUM = _SWITCHHOSTLINK_HOSTTYPE.enum_types_by_name['Enum']
_SWITCHHOSTLINK_CHOICE_ENUM = _SWITCHHOSTLINK_CHOICE.enum_types_by_name['Enum']
_L1SETTINGSPROFILE_LINKSPEED_ENUM = _L1SETTINGSPROFILE_LINKSPEED.enum_types_by_name['Enum']
_L1SETTINGSPROFILE_CHOICE_ENUM = _L1SETTINGSPROFILE_CHOICE.enum_types_by_name['Enum']
_L1SETTINGSPROFILEMANUAL_FECMODE_ENUM = _L1SETTINGSPROFILEMANUAL_FECMODE.enum_types_by_name['Enum']
_CHAOSDROPFRAMES_MODE_ENUM = _CHAOSDROPFRAMES_MODE.enum_types_by_name['Enum']
_CHAOSBACKGROUNDTRAFFICFLOW_CHOICE_ENUM = _CHAOSBACKGROUNDTRAFFICFLOW_CHOICE.enum_types_by_name['Enum']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESS_TRANSMISSIONMODE_ENUM = _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS_TRANSMISSIONMODE.enum_types_by_name['Enum']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET_L4PROTOCOL_ENUM = _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET_L4PROTOCOL.enum_types_by_name['Enum']
_CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST_UNIT_ENUM = _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST_UNIT.enum_types_by_name['Enum']
_INSIGHTSPORTMIRRORING_MIRRORTYPE_ENUM = _INSIGHTSPORTMIRRORING_MIRRORTYPE.enum_types_by_name['Enum']
_STATEREQUESTCHAOSBACKGROUNDTRAFFIC_STATE_ENUM = _STATEREQUESTCHAOSBACKGROUNDTRAFFIC_STATE.enum_types_by_name['Enum']
_STATEREQUESTCHAOSDROPFRAMES_STATE_ENUM = _STATEREQUESTCHAOSDROPFRAMES_STATE.enum_types_by_name['Enum']
OpenApiMsgOpt = _reflection.GeneratedProtocolMessageType('OpenApiMsgOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPIMSGOPT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.OpenApiMsgOpt)
  })
_sym_db.RegisterMessage(OpenApiMsgOpt)

OpenApiFldOpt = _reflection.GeneratedProtocolMessageType('OpenApiFldOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPIFLDOPT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.OpenApiFldOpt)
  })
_sym_db.RegisterMessage(OpenApiFldOpt)

OpenApiSvcOpt = _reflection.GeneratedProtocolMessageType('OpenApiSvcOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPISVCOPT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.OpenApiSvcOpt)
  })
_sym_db.RegisterMessage(OpenApiSvcOpt)

OpenApiRpcOpt = _reflection.GeneratedProtocolMessageType('OpenApiRpcOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPIRPCOPT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.OpenApiRpcOpt)
  })
_sym_db.RegisterMessage(OpenApiRpcOpt)

GlobalNamedObject = _reflection.GeneratedProtocolMessageType('GlobalNamedObject', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALNAMEDOBJECT,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.GlobalNamedObject)
  })
_sym_db.RegisterMessage(GlobalNamedObject)

ErrorDetails = _reflection.GeneratedProtocolMessageType('ErrorDetails', (_message.Message,), {
  'DESCRIPTOR' : _ERRORDETAILS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ErrorDetails)
  })
_sym_db.RegisterMessage(ErrorDetails)

WarningDetails = _reflection.GeneratedProtocolMessageType('WarningDetails', (_message.Message,), {
  'DESCRIPTOR' : _WARNINGDETAILS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.WarningDetails)
  })
_sym_db.RegisterMessage(WarningDetails)

ErrorItem = _reflection.GeneratedProtocolMessageType('ErrorItem', (_message.Message,), {
  'DESCRIPTOR' : _ERRORITEM,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ErrorItem)
  })
_sym_db.RegisterMessage(ErrorItem)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.Config)
  })
_sym_db.RegisterMessage(Config)

Host = _reflection.GeneratedProtocolMessageType('Host', (_message.Message,), {
  'DESCRIPTOR' : _HOST,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.Host)
  })
_sym_db.RegisterMessage(Host)

Fabric = _reflection.GeneratedProtocolMessageType('Fabric', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FABRIC_CHOICE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.Fabric.Choice)
    })
  ,
  'DESCRIPTOR' : _FABRIC,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.Fabric)
  })
_sym_db.RegisterMessage(Fabric)
_sym_db.RegisterMessage(Fabric.Choice)

FabricClos = _reflection.GeneratedProtocolMessageType('FabricClos', (_message.Message,), {
  'DESCRIPTOR' : _FABRICCLOS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricClos)
  })
_sym_db.RegisterMessage(FabricClos)

FabricSpine = _reflection.GeneratedProtocolMessageType('FabricSpine', (_message.Message,), {

  'DownlinkEcmpMode' : _reflection.GeneratedProtocolMessageType('DownlinkEcmpMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICSPINE_DOWNLINKECMPMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricSpine.DownlinkEcmpMode)
    })
  ,
  'DESCRIPTOR' : _FABRICSPINE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricSpine)
  })
_sym_db.RegisterMessage(FabricSpine)
_sym_db.RegisterMessage(FabricSpine.DownlinkEcmpMode)

FabricPod = _reflection.GeneratedProtocolMessageType('FabricPod', (_message.Message,), {
  'DESCRIPTOR' : _FABRICPOD,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPod)
  })
_sym_db.RegisterMessage(FabricPod)

FabricPodProfile = _reflection.GeneratedProtocolMessageType('FabricPodProfile', (_message.Message,), {
  'DESCRIPTOR' : _FABRICPODPROFILE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPodProfile)
  })
_sym_db.RegisterMessage(FabricPodProfile)

FabricPodSwitch = _reflection.GeneratedProtocolMessageType('FabricPodSwitch', (_message.Message,), {

  'UplinkEcmpMode' : _reflection.GeneratedProtocolMessageType('UplinkEcmpMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICPODSWITCH_UPLINKECMPMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPodSwitch.UplinkEcmpMode)
    })
  ,

  'DownlinkEcmpMode' : _reflection.GeneratedProtocolMessageType('DownlinkEcmpMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICPODSWITCH_DOWNLINKECMPMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPodSwitch.DownlinkEcmpMode)
    })
  ,
  'DESCRIPTOR' : _FABRICPODSWITCH,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricPodSwitch)
  })
_sym_db.RegisterMessage(FabricPodSwitch)
_sym_db.RegisterMessage(FabricPodSwitch.UplinkEcmpMode)
_sym_db.RegisterMessage(FabricPodSwitch.DownlinkEcmpMode)

FabricTor = _reflection.GeneratedProtocolMessageType('FabricTor', (_message.Message,), {
  'DESCRIPTOR' : _FABRICTOR,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricTor)
  })
_sym_db.RegisterMessage(FabricTor)

FabricTorProfile = _reflection.GeneratedProtocolMessageType('FabricTorProfile', (_message.Message,), {

  'TorMode' : _reflection.GeneratedProtocolMessageType('TorMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICTORPROFILE_TORMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricTorProfile.TorMode)
    })
  ,

  'UplinkEcmpMode' : _reflection.GeneratedProtocolMessageType('UplinkEcmpMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICTORPROFILE_UPLINKECMPMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricTorProfile.UplinkEcmpMode)
    })
  ,
  'DESCRIPTOR' : _FABRICTORPROFILE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricTorProfile)
  })
_sym_db.RegisterMessage(FabricTorProfile)
_sym_db.RegisterMessage(FabricTorProfile.TorMode)
_sym_db.RegisterMessage(FabricTorProfile.UplinkEcmpMode)

FabricTorProfileOversubscription = _reflection.GeneratedProtocolMessageType('FabricTorProfileOversubscription', (_message.Message,), {

  'Mode' : _reflection.GeneratedProtocolMessageType('Mode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICTORPROFILEOVERSUBSCRIPTION_MODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricTorProfileOversubscription.Mode)
    })
  ,
  'DESCRIPTOR' : _FABRICTORPROFILEOVERSUBSCRIPTION,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricTorProfileOversubscription)
  })
_sym_db.RegisterMessage(FabricTorProfileOversubscription)
_sym_db.RegisterMessage(FabricTorProfileOversubscription.Mode)

FabricQosProfile = _reflection.GeneratedProtocolMessageType('FabricQosProfile', (_message.Message,), {
  'DESCRIPTOR' : _FABRICQOSPROFILE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfile)
  })
_sym_db.RegisterMessage(FabricQosProfile)

FabricQosProfileIngressAdmission = _reflection.GeneratedProtocolMessageType('FabricQosProfileIngressAdmission', (_message.Message,), {
  'DESCRIPTOR' : _FABRICQOSPROFILEINGRESSADMISSION,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfileIngressAdmission)
  })
_sym_db.RegisterMessage(FabricQosProfileIngressAdmission)

FabricQosProfileScheduler = _reflection.GeneratedProtocolMessageType('FabricQosProfileScheduler', (_message.Message,), {

  'SchedulerMode' : _reflection.GeneratedProtocolMessageType('SchedulerMode', (_message.Message,), {
    'DESCRIPTOR' : _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfileScheduler.SchedulerMode)
    })
  ,
  'DESCRIPTOR' : _FABRICQOSPROFILESCHEDULER,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfileScheduler)
  })
_sym_db.RegisterMessage(FabricQosProfileScheduler)
_sym_db.RegisterMessage(FabricQosProfileScheduler.SchedulerMode)

FabricQosProfilePacketClassification = _reflection.GeneratedProtocolMessageType('FabricQosProfilePacketClassification', (_message.Message,), {
  'DESCRIPTOR' : _FABRICQOSPROFILEPACKETCLASSIFICATION,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfilePacketClassification)
  })
_sym_db.RegisterMessage(FabricQosProfilePacketClassification)

FabricQosProfilePacketClassificationMap = _reflection.GeneratedProtocolMessageType('FabricQosProfilePacketClassificationMap', (_message.Message,), {
  'DESCRIPTOR' : _FABRICQOSPROFILEPACKETCLASSIFICATIONMAP,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfilePacketClassificationMap)
  })
_sym_db.RegisterMessage(FabricQosProfilePacketClassificationMap)

FabricQosProfileWred = _reflection.GeneratedProtocolMessageType('FabricQosProfileWred', (_message.Message,), {
  'DESCRIPTOR' : _FABRICQOSPROFILEWRED,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.FabricQosProfileWred)
  })
_sym_db.RegisterMessage(FabricQosProfileWred)

SwitchHostLink = _reflection.GeneratedProtocolMessageType('SwitchHostLink', (_message.Message,), {

  'HostType' : _reflection.GeneratedProtocolMessageType('HostType', (_message.Message,), {
    'DESCRIPTOR' : _SWITCHHOSTLINK_HOSTTYPE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.SwitchHostLink.HostType)
    })
  ,

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _SWITCHHOSTLINK_CHOICE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.SwitchHostLink.Choice)
    })
  ,
  'DESCRIPTOR' : _SWITCHHOSTLINK,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SwitchHostLink)
  })
_sym_db.RegisterMessage(SwitchHostLink)
_sym_db.RegisterMessage(SwitchHostLink.HostType)
_sym_db.RegisterMessage(SwitchHostLink.Choice)

SwitchHostLinkSwitchRef = _reflection.GeneratedProtocolMessageType('SwitchHostLinkSwitchRef', (_message.Message,), {
  'DESCRIPTOR' : _SWITCHHOSTLINKSWITCHREF,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SwitchHostLinkSwitchRef)
  })
_sym_db.RegisterMessage(SwitchHostLinkSwitchRef)

L1SettingsProfile = _reflection.GeneratedProtocolMessageType('L1SettingsProfile', (_message.Message,), {

  'LinkSpeed' : _reflection.GeneratedProtocolMessageType('LinkSpeed', (_message.Message,), {
    'DESCRIPTOR' : _L1SETTINGSPROFILE_LINKSPEED,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.L1SettingsProfile.LinkSpeed)
    })
  ,

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _L1SETTINGSPROFILE_CHOICE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.L1SettingsProfile.Choice)
    })
  ,
  'DESCRIPTOR' : _L1SETTINGSPROFILE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.L1SettingsProfile)
  })
_sym_db.RegisterMessage(L1SettingsProfile)
_sym_db.RegisterMessage(L1SettingsProfile.LinkSpeed)
_sym_db.RegisterMessage(L1SettingsProfile.Choice)

L1SettingsProfileAutonegotiation = _reflection.GeneratedProtocolMessageType('L1SettingsProfileAutonegotiation', (_message.Message,), {
  'DESCRIPTOR' : _L1SETTINGSPROFILEAUTONEGOTIATION,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.L1SettingsProfileAutonegotiation)
  })
_sym_db.RegisterMessage(L1SettingsProfileAutonegotiation)

L1SettingsProfileManual = _reflection.GeneratedProtocolMessageType('L1SettingsProfileManual', (_message.Message,), {

  'FecMode' : _reflection.GeneratedProtocolMessageType('FecMode', (_message.Message,), {
    'DESCRIPTOR' : _L1SETTINGSPROFILEMANUAL_FECMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.L1SettingsProfileManual.FecMode)
    })
  ,
  'DESCRIPTOR' : _L1SETTINGSPROFILEMANUAL,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.L1SettingsProfileManual)
  })
_sym_db.RegisterMessage(L1SettingsProfileManual)
_sym_db.RegisterMessage(L1SettingsProfileManual.FecMode)

Chaos = _reflection.GeneratedProtocolMessageType('Chaos', (_message.Message,), {
  'DESCRIPTOR' : _CHAOS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.Chaos)
  })
_sym_db.RegisterMessage(Chaos)

ChaosDropFrames = _reflection.GeneratedProtocolMessageType('ChaosDropFrames', (_message.Message,), {

  'Mode' : _reflection.GeneratedProtocolMessageType('Mode', (_message.Message,), {
    'DESCRIPTOR' : _CHAOSDROPFRAMES_MODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosDropFrames.Mode)
    })
  ,
  'DESCRIPTOR' : _CHAOSDROPFRAMES,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosDropFrames)
  })
_sym_db.RegisterMessage(ChaosDropFrames)
_sym_db.RegisterMessage(ChaosDropFrames.Mode)

ChaosBackgroundTraffic = _reflection.GeneratedProtocolMessageType('ChaosBackgroundTraffic', (_message.Message,), {
  'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFIC,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTraffic)
  })
_sym_db.RegisterMessage(ChaosBackgroundTraffic)

ChaosBackgroundTrafficFlow = _reflection.GeneratedProtocolMessageType('ChaosBackgroundTrafficFlow', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFICFLOW_CHOICE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTrafficFlow.Choice)
    })
  ,
  'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFICFLOW,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTrafficFlow)
  })
_sym_db.RegisterMessage(ChaosBackgroundTrafficFlow)
_sym_db.RegisterMessage(ChaosBackgroundTrafficFlow.Choice)

ChaosBackgroundTrafficFlowStateless = _reflection.GeneratedProtocolMessageType('ChaosBackgroundTrafficFlowStateless', (_message.Message,), {

  'TransmissionMode' : _reflection.GeneratedProtocolMessageType('TransmissionMode', (_message.Message,), {
    'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS_TRANSMISSIONMODE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTrafficFlowStateless.TransmissionMode)
    })
  ,
  'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTrafficFlowStateless)
  })
_sym_db.RegisterMessage(ChaosBackgroundTrafficFlowStateless)
_sym_db.RegisterMessage(ChaosBackgroundTrafficFlowStateless.TransmissionMode)

ChaosBackgroundTrafficFlowStatelessPacket = _reflection.GeneratedProtocolMessageType('ChaosBackgroundTrafficFlowStatelessPacket', (_message.Message,), {

  'L4Protocol' : _reflection.GeneratedProtocolMessageType('L4Protocol', (_message.Message,), {
    'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET_L4PROTOCOL,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTrafficFlowStatelessPacket.L4Protocol)
    })
  ,
  'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTrafficFlowStatelessPacket)
  })
_sym_db.RegisterMessage(ChaosBackgroundTrafficFlowStatelessPacket)
_sym_db.RegisterMessage(ChaosBackgroundTrafficFlowStatelessPacket.L4Protocol)

ChaosBackgroundTrafficFlowStatelessPacketDsField = _reflection.GeneratedProtocolMessageType('ChaosBackgroundTrafficFlowStatelessPacketDsField', (_message.Message,), {
  'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTrafficFlowStatelessPacketDsField)
  })
_sym_db.RegisterMessage(ChaosBackgroundTrafficFlowStatelessPacketDsField)

ChaosBackgroundTrafficFlowStatelessBurst = _reflection.GeneratedProtocolMessageType('ChaosBackgroundTrafficFlowStatelessBurst', (_message.Message,), {

  'Unit' : _reflection.GeneratedProtocolMessageType('Unit', (_message.Message,), {
    'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST_UNIT,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTrafficFlowStatelessBurst.Unit)
    })
  ,
  'DESCRIPTOR' : _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.ChaosBackgroundTrafficFlowStatelessBurst)
  })
_sym_db.RegisterMessage(ChaosBackgroundTrafficFlowStatelessBurst)
_sym_db.RegisterMessage(ChaosBackgroundTrafficFlowStatelessBurst.Unit)

Insights = _reflection.GeneratedProtocolMessageType('Insights', (_message.Message,), {
  'DESCRIPTOR' : _INSIGHTS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.Insights)
  })
_sym_db.RegisterMessage(Insights)

InsightsPortMirroring = _reflection.GeneratedProtocolMessageType('InsightsPortMirroring', (_message.Message,), {

  'MirrorType' : _reflection.GeneratedProtocolMessageType('MirrorType', (_message.Message,), {
    'DESCRIPTOR' : _INSIGHTSPORTMIRRORING_MIRRORTYPE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.InsightsPortMirroring.MirrorType)
    })
  ,
  'DESCRIPTOR' : _INSIGHTSPORTMIRRORING,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.InsightsPortMirroring)
  })
_sym_db.RegisterMessage(InsightsPortMirroring)
_sym_db.RegisterMessage(InsightsPortMirroring.MirrorType)

StateRequest = _reflection.GeneratedProtocolMessageType('StateRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATEREQUEST,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.StateRequest)
  })
_sym_db.RegisterMessage(StateRequest)

StateRequestChaos = _reflection.GeneratedProtocolMessageType('StateRequestChaos', (_message.Message,), {
  'DESCRIPTOR' : _STATEREQUESTCHAOS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.StateRequestChaos)
  })
_sym_db.RegisterMessage(StateRequestChaos)

StateRequestChaosBackgroundTraffic = _reflection.GeneratedProtocolMessageType('StateRequestChaosBackgroundTraffic', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _STATEREQUESTCHAOSBACKGROUNDTRAFFIC_STATE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.StateRequestChaosBackgroundTraffic.State)
    })
  ,
  'DESCRIPTOR' : _STATEREQUESTCHAOSBACKGROUNDTRAFFIC,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.StateRequestChaosBackgroundTraffic)
  })
_sym_db.RegisterMessage(StateRequestChaosBackgroundTraffic)
_sym_db.RegisterMessage(StateRequestChaosBackgroundTraffic.State)

StateRequestChaosDropFrames = _reflection.GeneratedProtocolMessageType('StateRequestChaosDropFrames', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _STATEREQUESTCHAOSDROPFRAMES_STATE,
    '__module__' : 'onexfabricapi_pb2'
    # @@protoc_insertion_point(class_scope:onexfabricapi.StateRequestChaosDropFrames.State)
    })
  ,
  'DESCRIPTOR' : _STATEREQUESTCHAOSDROPFRAMES,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.StateRequestChaosDropFrames)
  })
_sym_db.RegisterMessage(StateRequestChaosDropFrames)
_sym_db.RegisterMessage(StateRequestChaosDropFrames.State)

StateResponse = _reflection.GeneratedProtocolMessageType('StateResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATERESPONSE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.StateResponse)
  })
_sym_db.RegisterMessage(StateResponse)

StateResponseChaos = _reflection.GeneratedProtocolMessageType('StateResponseChaos', (_message.Message,), {
  'DESCRIPTOR' : _STATERESPONSECHAOS,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.StateResponseChaos)
  })
_sym_db.RegisterMessage(StateResponseChaos)

StateResponseChaosBackgroundTraffic = _reflection.GeneratedProtocolMessageType('StateResponseChaosBackgroundTraffic', (_message.Message,), {
  'DESCRIPTOR' : _STATERESPONSECHAOSBACKGROUNDTRAFFIC,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.StateResponseChaosBackgroundTraffic)
  })
_sym_db.RegisterMessage(StateResponseChaosBackgroundTraffic)

StateResponseChaosDropFrames = _reflection.GeneratedProtocolMessageType('StateResponseChaosDropFrames', (_message.Message,), {
  'DESCRIPTOR' : _STATERESPONSECHAOSDROPFRAMES,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.StateResponseChaosDropFrames)
  })
_sym_db.RegisterMessage(StateResponseChaosDropFrames)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)

SetStateRequest = _reflection.GeneratedProtocolMessageType('SetStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETSTATEREQUEST,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SetStateRequest)
  })
_sym_db.RegisterMessage(SetStateRequest)

SetStateResponse = _reflection.GeneratedProtocolMessageType('SetStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETSTATERESPONSE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.SetStateResponse)
  })
_sym_db.RegisterMessage(SetStateResponse)

GetStateResponse = _reflection.GeneratedProtocolMessageType('GetStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATERESPONSE,
  '__module__' : 'onexfabricapi_pb2'
  # @@protoc_insertion_point(class_scope:onexfabricapi.GetStateResponse)
  })
_sym_db.RegisterMessage(GetStateResponse)

_OPENAPI = DESCRIPTOR.services_by_name['Openapi']
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(msg_meta)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(fld_meta)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(svc_meta)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(rpc_meta)

  DESCRIPTOR._options = None
  _GLOBALNAMEDOBJECT.fields_by_name['name']._options = None
  _GLOBALNAMEDOBJECT.fields_by_name['name']._serialized_options = b'\222\246\035\"\242\001\037Unique identifier for an object'
  _GLOBALNAMEDOBJECT._options = None
  _GLOBALNAMEDOBJECT._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _ERRORDETAILS.fields_by_name['errors']._options = None
  _ERRORDETAILS.fields_by_name['errors']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _ERRORDETAILS._options = None
  _ERRORDETAILS._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _WARNINGDETAILS.fields_by_name['warnings']._options = None
  _WARNINGDETAILS.fields_by_name['warnings']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _WARNINGDETAILS._options = None
  _WARNINGDETAILS._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _ERRORITEM.fields_by_name['message']._options = None
  _ERRORITEM.fields_by_name['message']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _ERRORITEM.fields_by_name['code']._options = None
  _ERRORITEM.fields_by_name['code']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _ERRORITEM.fields_by_name['detail']._options = None
  _ERRORITEM.fields_by_name['detail']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _ERRORITEM._options = None
  _ERRORITEM._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _CONFIG.fields_by_name['hosts']._options = None
  _CONFIG.fields_by_name['hosts']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CONFIG.fields_by_name['fabric']._options = None
  _CONFIG.fields_by_name['fabric']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CONFIG.fields_by_name['layer1_profiles']._options = None
  _CONFIG.fields_by_name['layer1_profiles']._serialized_options = b'\222\246\035&\242\001#A list of Layer 1 settings profiles'
  _CONFIG.fields_by_name['chaos']._options = None
  _CONFIG.fields_by_name['chaos']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CONFIG.fields_by_name['insights']._options = None
  _CONFIG.fields_by_name['insights']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CONFIG._options = None
  _CONFIG._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _HOST.fields_by_name['name']._options = None
  _HOST.fields_by_name['name']._serialized_options = b'\222\246\035*\242\001\'The name, uniquely identifying the host'
  _HOST.fields_by_name['address']._options = None
  _HOST.fields_by_name['address']._serialized_options = b'\222\246\035\037\242\001\034The test address of the host'
  _HOST.fields_by_name['prefix']._options = None
  _HOST.fields_by_name['prefix']._serialized_options = b'\222\246\035\004R\00224\222\246\035\031\242\001\026The prefix of the host'
  _HOST.fields_by_name['l1_profile_name']._options = None
  _HOST.fields_by_name['l1_profile_name']._serialized_options = b'\222\246\035\262\001\242\001\256\001The layer 1 settings profile associated with the host/front panel port.\n\nx-constraint:\n- ../l1settings/l1_profiles.yaml#/components/schemas/L1SettingsProfile/properties/name\n'
  _HOST._options = None
  _HOST._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRIC.fields_by_name['choice']._options = None
  _FABRIC.fields_by_name['choice']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRIC.fields_by_name['clos']._options = None
  _FABRIC.fields_by_name['clos']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRIC.fields_by_name['qos_profiles']._options = None
  _FABRIC.fields_by_name['qos_profiles']._serialized_options = b'\222\246\035.\242\001+A list of Quality of Service (QoS) profiles'
  _FABRIC._options = None
  _FABRIC._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICCLOS.fields_by_name['spine']._options = None
  _FABRICCLOS.fields_by_name['spine']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICCLOS.fields_by_name['pods']._options = None
  _FABRICCLOS.fields_by_name['pods']._serialized_options = b'\222\246\035\034\242\001\031The pods in the topology.'
  _FABRICCLOS.fields_by_name['host_links']._options = None
  _FABRICCLOS.fields_by_name['host_links']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICCLOS.fields_by_name['pod_profiles']._options = None
  _FABRICCLOS.fields_by_name['pod_profiles']._serialized_options = b'\222\246\035\031\242\001\026A list of pod profiles'
  _FABRICCLOS.fields_by_name['tor_profiles']._options = None
  _FABRICCLOS.fields_by_name['tor_profiles']._serialized_options = b'\222\246\035 \242\001\035A list of ToR switch profiles'
  _FABRICCLOS.fields_by_name['parallel_fabric_count']._options = None
  _FABRICCLOS.fields_by_name['parallel_fabric_count']._serialized_options = b'\222\246\035\003R\0011\222\246\035k\242\001hNumber of parallel fabrics (aka fabric colors). Spine and pod switches \nare fully meshed within a fabric'
  _FABRICCLOS._options = None
  _FABRICCLOS._serialized_options = b'\212\246\035\220\001R\215\001An emulation of a multistage switch topology. When folded, results in a topology with (up to) 3 tiers identified as \nspine, pod and tor tier.'
  _FABRICSPINE.fields_by_name['count']._options = None
  _FABRICSPINE.fields_by_name['count']._serialized_options = b'\222\246\035\003R\0011\222\246\035z\242\001wThe number of spines to be created with each spine sharing the same\ndownlink_ecmp_mode and qos_profile_name properties.'
  _FABRICSPINE.fields_by_name['downlink_ecmp_mode']._options = None
  _FABRICSPINE.fields_by_name['downlink_ecmp_mode']._serialized_options = b'\222\246\035\210\002\242\001\204\002The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash mode'
  _FABRICSPINE.fields_by_name['qos_profile_name']._options = None
  _FABRICSPINE.fields_by_name['qos_profile_name']._serialized_options = b'\222\246\035t\242\001qThe name of a qos profile shared by the spines.\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\n'
  _FABRICSPINE._options = None
  _FABRICSPINE._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICPOD.fields_by_name['count']._options = None
  _FABRICPOD.fields_by_name['count']._serialized_options = b'\222\246\035\003R\0011\222\246\0356\242\0013The number of pods that will share the same profile'
  _FABRICPOD.fields_by_name['pod_profile_name']._options = None
  _FABRICPOD.fields_by_name['pod_profile_name']._serialized_options = b'\222\246\035p\242\001mThe pod profile associated with the pod(s).\n\nx-constraint:\n- #/components/schemas/PodProfile/properties/name\n'
  _FABRICPOD._options = None
  _FABRICPOD._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICPODPROFILE.fields_by_name['name']._options = None
  _FABRICPODPROFILE.fields_by_name['name']._serialized_options = b'\222\246\035$\242\001!Uniquely identifies a pod profile'
  _FABRICPODPROFILE.fields_by_name['pod_switch']._options = None
  _FABRICPODPROFILE.fields_by_name['pod_switch']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICPODPROFILE.fields_by_name['tors']._options = None
  _FABRICPODPROFILE.fields_by_name['tors']._serialized_options = b'\222\246\035\026\242\001\023The ToRs in the pod'
  _FABRICPODPROFILE.fields_by_name['pod_to_spine_oversubscription']._options = None
  _FABRICPODPROFILE.fields_by_name['pod_to_spine_oversubscription']._serialized_options = b'\222\246\035-\242\001*Oversubscription ratio of the pod switches'
  _FABRICPODPROFILE._options = None
  _FABRICPODPROFILE._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICPODSWITCH.fields_by_name['count']._options = None
  _FABRICPODSWITCH.fields_by_name['count']._serialized_options = b'\222\246\035\003R\0011\222\246\035 \242\001\035Description missing in models'
  _FABRICPODSWITCH.fields_by_name['uplink_ecmp_mode']._options = None
  _FABRICPODSWITCH.fields_by_name['uplink_ecmp_mode']._serialized_options = b'\222\246\035\210\002\242\001\204\002The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash mode'
  _FABRICPODSWITCH.fields_by_name['downlink_ecmp_mode']._options = None
  _FABRICPODSWITCH.fields_by_name['downlink_ecmp_mode']._serialized_options = b'\222\246\035\210\002\242\001\204\002The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash mode'
  _FABRICPODSWITCH.fields_by_name['qos_profile_name']._options = None
  _FABRICPODSWITCH.fields_by_name['qos_profile_name']._serialized_options = b'\222\246\035\211\001\242\001\205\001The name of a qos profile associated with the switches in this pod.\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\n'
  _FABRICPODSWITCH._options = None
  _FABRICPODSWITCH._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICTOR.fields_by_name['count']._options = None
  _FABRICTOR.fields_by_name['count']._serialized_options = b'\222\246\035\003R\0011\222\246\035:\242\0017number of ToR switches that will share the same profile'
  _FABRICTOR.fields_by_name['tor_profile_name']._options = None
  _FABRICTOR.fields_by_name['tor_profile_name']._serialized_options = b'\222\246\035\201\001\242\001~The names of ToR profiles associated with the ToR switch(es)\n\nx-constraint:\n- #/components/schemas/TorProfile/properties/name\n'
  _FABRICTOR._options = None
  _FABRICTOR._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICTORPROFILE.fields_by_name['name']._options = None
  _FABRICTORPROFILE.fields_by_name['name']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICTORPROFILE.fields_by_name['tor_mode']._options = None
  _FABRICTORPROFILE.fields_by_name['tor_mode']._serialized_options = b'\222\246\035\022\242\001\017ToR switch mode'
  _FABRICTORPROFILE.fields_by_name['uplink_ecmp_mode']._options = None
  _FABRICTORPROFILE.fields_by_name['uplink_ecmp_mode']._serialized_options = b'\222\246\035\210\002\242\001\204\002The algorithm for packet distribution over ECMP links.\n- random_spray randomly puts each packet on an ECMP member links \n- hash_3_tuple is a 3 tuple hash of ipv4 src, dst, protocol\n- hash_5_tuple is static_hash_ipv4_l4 but a different resulting RTAG7 hash mode'
  _FABRICTORPROFILE.fields_by_name['qos_profile_name']._options = None
  _FABRICTORPROFILE.fields_by_name['qos_profile_name']._serialized_options = b'\222\246\035\201\001\242\001~The name of a qos profile associated with the ToR switch(es)\n\nx-constraint:\n- #/components/schemas/QosProfile/properties/name\n'
  _FABRICTORPROFILE.fields_by_name['tor_to_pod_oversubscription']._options = None
  _FABRICTORPROFILE.fields_by_name['tor_to_pod_oversubscription']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICTORPROFILE._options = None
  _FABRICTORPROFILE._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICTORPROFILEOVERSUBSCRIPTION.fields_by_name['ratio']._options = None
  _FABRICTORPROFILEOVERSUBSCRIPTION.fields_by_name['ratio']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICTORPROFILEOVERSUBSCRIPTION.fields_by_name['mode']._options = None
  _FABRICTORPROFILEOVERSUBSCRIPTION.fields_by_name['mode']._serialized_options = b'\222\246\035\035R\033Mode.Enum.use_host_capacity\222\246\035 \242\001\035Description missing in models'
  _FABRICTORPROFILEOVERSUBSCRIPTION.fields_by_name['host_capacity']._options = None
  _FABRICTORPROFILEOVERSUBSCRIPTION.fields_by_name['host_capacity']._serialized_options = b'\222\246\035\003R\0011\222\246\035 \242\001\035Description missing in models'
  _FABRICTORPROFILEOVERSUBSCRIPTION._options = None
  _FABRICTORPROFILEOVERSUBSCRIPTION._serialized_options = b'\212\246\035,R*The oversubscription of the ToR switch(es)'
  _FABRICQOSPROFILE.fields_by_name['name']._options = None
  _FABRICQOSPROFILE.fields_by_name['name']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICQOSPROFILE.fields_by_name['ingress_admission']._options = None
  _FABRICQOSPROFILE.fields_by_name['ingress_admission']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICQOSPROFILE.fields_by_name['scheduler']._options = None
  _FABRICQOSPROFILE.fields_by_name['scheduler']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICQOSPROFILE.fields_by_name['packet_classification']._options = None
  _FABRICQOSPROFILE.fields_by_name['packet_classification']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICQOSPROFILE.fields_by_name['wred']._options = None
  _FABRICQOSPROFILE.fields_by_name['wred']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICQOSPROFILE._options = None
  _FABRICQOSPROFILE._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['reserved_buffer_bytes']._options = None
  _FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['reserved_buffer_bytes']._serialized_options = b'\222\246\035\003R\0010\222\246\035R\242\001OBuffer space (in bytes) reserved for each port that this Qos profile applies to'
  _FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['shared_buffer_bytes']._options = None
  _FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['shared_buffer_bytes']._serialized_options = b'\222\246\035\003R\0010\222\246\0355\242\0012Amount of shared buffer space (in bytes) available'
  _FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['priority_list']._options = None
  _FABRICQOSPROFILEINGRESSADMISSION.fields_by_name['priority_list']._serialized_options = b'\222\246\035B\242\001?List of priorities for which the buffer sizes should be applied'
  _FABRICQOSPROFILEINGRESSADMISSION._options = None
  _FABRICQOSPROFILEINGRESSADMISSION._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICQOSPROFILESCHEDULER.fields_by_name['scheduler_mode']._options = None
  _FABRICQOSPROFILESCHEDULER.fields_by_name['scheduler_mode']._serialized_options = b'\222\246\035#\242\001 The queue scheduling discipline '
  _FABRICQOSPROFILESCHEDULER.fields_by_name['weight_list']._options = None
  _FABRICQOSPROFILESCHEDULER.fields_by_name['weight_list']._serialized_options = b'\222\246\035I\242\001FA list of egress queue weights for weighted round robin scheduler mode'
  _FABRICQOSPROFILESCHEDULER._options = None
  _FABRICQOSPROFILESCHEDULER._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_dscp_to_traffic_class']._options = None
  _FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_dscp_to_traffic_class']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_traffic_class_to_queue']._options = None
  _FABRICQOSPROFILEPACKETCLASSIFICATION.fields_by_name['map_traffic_class_to_queue']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _FABRICQOSPROFILEPACKETCLASSIFICATION._options = None
  _FABRICQOSPROFILEPACKETCLASSIFICATION._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICQOSPROFILEPACKETCLASSIFICATIONMAP._options = None
  _FABRICQOSPROFILEPACKETCLASSIFICATIONMAP._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _FABRICQOSPROFILEWRED.fields_by_name['queue_list']._options = None
  _FABRICQOSPROFILEWRED.fields_by_name['queue_list']._serialized_options = b'\222\246\035+\242\001(List of queues for which WRED is enabled'
  _FABRICQOSPROFILEWRED.fields_by_name['ecn_marking_enabled']._options = None
  _FABRICQOSPROFILEWRED.fields_by_name['ecn_marking_enabled']._serialized_options = b'\222\246\035\007R\005False\222\246\035 \242\001\035Description missing in models'
  _FABRICQOSPROFILEWRED.fields_by_name['min_threshold_bytes']._options = None
  _FABRICQOSPROFILEWRED.fields_by_name['min_threshold_bytes']._serialized_options = b'\222\246\035\003R\0011\222\246\035H\242\001EEgress queue threshold beyond which packets will be droppes or marked'
  _FABRICQOSPROFILEWRED.fields_by_name['max_threshold_bytes']._options = None
  _FABRICQOSPROFILEWRED.fields_by_name['max_threshold_bytes']._serialized_options = b'\222\246\035\003R\0012\222\246\035H\242\001EEgress queue threshold beyond which packets will be droppes or marked'
  _FABRICQOSPROFILEWRED.fields_by_name['max_probability_percent']._options = None
  _FABRICQOSPROFILEWRED.fields_by_name['max_probability_percent']._serialized_options = b'\222\246\035\005R\003100\222\246\035;\242\0018Probability of dropping/marking packets at max threshold'
  _FABRICQOSPROFILEWRED._options = None
  _FABRICQOSPROFILEWRED._serialized_options = b'\212\246\0356R4WRED (weighted random early detection) configuration'
  _SWITCHHOSTLINK.fields_by_name['host_name']._options = None
  _SWITCHHOSTLINK.fields_by_name['host_name']._serialized_options = b'\222\246\035A\242\001>TBD\n\nx-constraint:\n- #components/schemas/Host/properties/name\n'
  _SWITCHHOSTLINK.fields_by_name['host_type']._options = None
  _SWITCHHOSTLINK.fields_by_name['host_type']._serialized_options = b'\222\246\035\030R\026HostType.Enum.external\222\246\035\241\002\242\001\235\002Optional host type, if fabric is rendered on physical box.\n- external for hosts/servers physically connected to front panel ports\n- internal_traffic_sink for an emulated server that acts as a traffic sink (i.e. packets sent to its IP address will be routed through the emulated fabric)'
  _SWITCHHOSTLINK.fields_by_name['front_panel_port']._options = None
  _SWITCHHOSTLINK.fields_by_name['front_panel_port']._serialized_options = b'\222\246\035J\242\001GOptional front panel port number, if fabric is rendered on physical box'
  _SWITCHHOSTLINK.fields_by_name['choice']._options = None
  _SWITCHHOSTLINK.fields_by_name['choice']._serialized_options = b'\222\246\035\021R\017Choice.Enum.tor\222\246\035 \242\001\035Description missing in models'
  _SWITCHHOSTLINK.fields_by_name['spine']._options = None
  _SWITCHHOSTLINK.fields_by_name['spine']._serialized_options = b'\222\246\035f\242\001cOne based index of the spine switch based on the number of spines \nconfigured in the clos topology.'
  _SWITCHHOSTLINK.fields_by_name['pod']._options = None
  _SWITCHHOSTLINK.fields_by_name['pod']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _SWITCHHOSTLINK.fields_by_name['tor']._options = None
  _SWITCHHOSTLINK.fields_by_name['tor']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _SWITCHHOSTLINK._options = None
  _SWITCHHOSTLINK._serialized_options = b'\212\246\035ORMThe ingress point of a host which is the index of a spine, pod or tor switch.'
  _SWITCHHOSTLINKSWITCHREF.fields_by_name['pod_index']._options = None
  _SWITCHHOSTLINKSWITCHREF.fields_by_name['pod_index']._serialized_options = b'\222\246\035\003R\0011\222\246\035G\242\001DOne-based index of the pod based on the number of pods in the fabric'
  _SWITCHHOSTLINKSWITCHREF.fields_by_name['switch_index']._options = None
  _SWITCHHOSTLINKSWITCHREF.fields_by_name['switch_index']._serialized_options = b'\222\246\035\003R\0011\222\246\035@\242\001=One-based index of the pod or ToR switch in the indicated pod'
  _SWITCHHOSTLINKSWITCHREF._options = None
  _SWITCHHOSTLINKSWITCHREF._serialized_options = b'\212\246\0356R4Location of the switch based on pod and switch index'
  _L1SETTINGSPROFILE.fields_by_name['name']._options = None
  _L1SETTINGSPROFILE.fields_by_name['name']._serialized_options = b'\222\246\0351\242\001.Uniquely identifies a layer 1 settings profile'
  _L1SETTINGSPROFILE.fields_by_name['link_speed']._options = None
  _L1SETTINGSPROFILE.fields_by_name['link_speed']._serialized_options = b'\222\246\035\037R\035LinkSpeed.Enum.speed_100_gbps\222\246\035\r\242\001\nLink speed'
  _L1SETTINGSPROFILE.fields_by_name['choice']._options = None
  _L1SETTINGSPROFILE.fields_by_name['choice']._serialized_options = b'\222\246\035\035R\033Choice.Enum.autonegotiation\222\246\035 \242\001\035Description missing in models'
  _L1SETTINGSPROFILE.fields_by_name['autonegotiation']._options = None
  _L1SETTINGSPROFILE.fields_by_name['autonegotiation']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _L1SETTINGSPROFILE.fields_by_name['manual']._options = None
  _L1SETTINGSPROFILE.fields_by_name['manual']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _L1SETTINGSPROFILE._options = None
  _L1SETTINGSPROFILE._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _L1SETTINGSPROFILEAUTONEGOTIATION.fields_by_name['advertise_fec']._options = None
  _L1SETTINGSPROFILEAUTONEGOTIATION.fields_by_name['advertise_fec']._serialized_options = b'\222\246\035\006R\004True\222\246\035 \242\001\035Description missing in models'
  _L1SETTINGSPROFILEAUTONEGOTIATION._options = None
  _L1SETTINGSPROFILEAUTONEGOTIATION._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _L1SETTINGSPROFILEMANUAL.fields_by_name['fec_mode']._options = None
  _L1SETTINGSPROFILEMANUAL.fields_by_name['fec_mode']._serialized_options = b'\222\246\035\033R\031FecMode.Enum.reed_solomon\222\246\035 \242\001\035Description missing in models'
  _L1SETTINGSPROFILEMANUAL._options = None
  _L1SETTINGSPROFILEMANUAL._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _CHAOS.fields_by_name['background_traffic']._options = None
  _CHAOS.fields_by_name['background_traffic']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOS.fields_by_name['drop_frames']._options = None
  _CHAOS.fields_by_name['drop_frames']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOS._options = None
  _CHAOS._serialized_options = b'\212\246\035$R\"Configuration of chaos experiments'
  _CHAOSDROPFRAMES.fields_by_name['name']._options = None
  _CHAOSDROPFRAMES.fields_by_name['name']._serialized_options = b'\222\246\0351\242\001.Uniquely identifies a drop frames config entry'
  _CHAOSDROPFRAMES.fields_by_name['link']._options = None
  _CHAOSDROPFRAMES.fields_by_name['link']._serialized_options = b'\222\246\035&\242\001#Emulated link name, e.g. Link S.1/2'
  _CHAOSDROPFRAMES.fields_by_name['mode']._options = None
  _CHAOSDROPFRAMES.fields_by_name['mode']._serialized_options = b'\222\246\035\033R\031Mode.Enum.percentage_time\222\246\035\211\001\242\001\205\001Mode to express the duration in which frames are dropped, either a percentage of the specified time interval or the min possible time'
  _CHAOSDROPFRAMES.fields_by_name['percentage']._options = None
  _CHAOSDROPFRAMES.fields_by_name['percentage']._serialized_options = b'\222\246\035\003R\0015\222\246\0350\242\001-Percentage value, ignored if type is min_time'
  _CHAOSDROPFRAMES.fields_by_name['interval']._options = None
  _CHAOSDROPFRAMES.fields_by_name['interval']._serialized_options = b'\222\246\035\003R\0011\222\246\035\035\242\001\032Interval of time (seconds)'
  _CHAOSDROPFRAMES._options = None
  _CHAOSDROPFRAMES._serialized_options = b'\212\246\035iRgConfigures an emulated link to periodically drop frames for a percentage of the specified time interval'
  _CHAOSBACKGROUNDTRAFFIC.fields_by_name['flows']._options = None
  _CHAOSBACKGROUNDTRAFFIC.fields_by_name['flows']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFIC._options = None
  _CHAOSBACKGROUNDTRAFFIC._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOW.fields_by_name['name']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOW.fields_by_name['name']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOW.fields_by_name['injection_port']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOW.fields_by_name['injection_port']._serialized_options = b'\222\246\0351\242\001.Emulated port name, e.g. Spine Switch 1 Port 1'
  _CHAOSBACKGROUNDTRAFFICFLOW.fields_by_name['choice']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOW.fields_by_name['choice']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOW.fields_by_name['stateless']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOW.fields_by_name['stateless']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOW._options = None
  _CHAOSBACKGROUNDTRAFFICFLOW._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS.fields_by_name['rate']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS.fields_by_name['rate']._serialized_options = b'\222\246\035J\242\001GTransmission rate specified as a percentage of the injection port speed'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS.fields_by_name['transmission_mode']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS.fields_by_name['transmission_mode']._serialized_options = b'\222\246\035\"R TransmissionMode.Enum.continuous\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS.fields_by_name['packet']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS.fields_by_name['packet']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS.fields_by_name['burst']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS.fields_by_name['burst']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['src_address']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['src_address']._serialized_options = b'\222\246\035\024\242\001\021source IP address'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['dst_address']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['dst_address']._serialized_options = b'\222\246\035\031\242\001\026destination IP address'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['src_port']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['src_port']._serialized_options = b'\222\246\035\006R\0041024\222\246\035\026\242\001\023Layer 4 source port'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['dst_port']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['dst_port']._serialized_options = b'\222\246\035\006R\0041024\222\246\035\033\242\001\030Layer 4 destination port'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['size']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['size']._serialized_options = b'\222\246\035\006R\0041000\222\246\035\024\242\001\021total packet size'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['l4_protocol']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['l4_protocol']._serialized_options = b'\222\246\035\035\242\001\032Layer 4 transport protocol'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['ds_field']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET.fields_by_name['ds_field']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD.fields_by_name['dscp']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD.fields_by_name['dscp']._serialized_options = b'\222\246\035\003R\0010\222\246\035)\242\001&Differentiated Service CodePoint filed'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD.fields_by_name['ecn']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD.fields_by_name['ecn']._serialized_options = b'\222\246\035\003R\0010\222\246\035)\242\001&Explicit Congestion Notification field'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD._serialized_options = b'\212\246\0350R.Differentiated Services or Traffic Class field'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST.fields_by_name['transmit_duration']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST.fields_by_name['transmit_duration']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST.fields_by_name['transmit_gap']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST.fields_by_name['transmit_gap']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST.fields_by_name['unit']._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST.fields_by_name['unit']._serialized_options = b'\222\246\035\016R\014Unit.Enum.ms\222\246\035 \242\001\035Description missing in models'
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST._options = None
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _INSIGHTS.fields_by_name['port_mirroring']._options = None
  _INSIGHTS.fields_by_name['port_mirroring']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _INSIGHTS._options = None
  _INSIGHTS._serialized_options = b'\212\246\035-R+Configuration of insights providing methods'
  _INSIGHTSPORTMIRRORING.fields_by_name['name']._options = None
  _INSIGHTSPORTMIRRORING.fields_by_name['name']._serialized_options = b'\222\246\0352\242\001/Uniquely identifies a port port_mirroring entry'
  _INSIGHTSPORTMIRRORING.fields_by_name['source_port']._options = None
  _INSIGHTSPORTMIRRORING.fields_by_name['source_port']._serialized_options = b'\222\246\035@\242\001=Emulated port name, e.g. Spine Switch 1 Port 1 to be mirrored'
  _INSIGHTSPORTMIRRORING.fields_by_name['destination_port']._options = None
  _INSIGHTSPORTMIRRORING.fields_by_name['destination_port']._serialized_options = b'\222\246\035J\242\001GFront panel port number of an external host, e.g. 32 on which to mirror'
  _INSIGHTSPORTMIRRORING.fields_by_name['mirror_type']._options = None
  _INSIGHTSPORTMIRRORING.fields_by_name['mirror_type']._serialized_options = b'\222\246\035 R\036MirrorType.Enum.ingress_frames\222\246\035 \242\001\035Description missing in models'
  _INSIGHTSPORTMIRRORING._options = None
  _INSIGHTSPORTMIRRORING._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _STATEREQUEST.fields_by_name['chaos']._options = None
  _STATEREQUEST.fields_by_name['chaos']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _STATEREQUEST._options = None
  _STATEREQUEST._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _STATEREQUESTCHAOS.fields_by_name['drop_frames']._options = None
  _STATEREQUESTCHAOS.fields_by_name['drop_frames']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _STATEREQUESTCHAOS.fields_by_name['background_traffic']._options = None
  _STATEREQUESTCHAOS.fields_by_name['background_traffic']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _STATEREQUESTCHAOS._options = None
  _STATEREQUESTCHAOS._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC.fields_by_name['flow_names']._options = None
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC.fields_by_name['flow_names']._serialized_options = b'\222\246\035\377\001\242\001\373\001The names of flows to which the transmit state will be applied to. If the list of flow_names is empty or null the state will be applied to all configured flows.\n\nx-constraint:\n- ../chaos/background_traffic.yaml/components/schemas/Flow/properties/name\n'
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC.fields_by_name['state']._options = None
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC.fields_by_name['state']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC._options = None
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _STATEREQUESTCHAOSDROPFRAMES.fields_by_name['config_names']._options = None
  _STATEREQUESTCHAOSDROPFRAMES.fields_by_name['config_names']._serialized_options = b'\222\246\035\376\001\242\001\372\001The names of the drop frams configs to which the transmit state will be applied to. If the list is empty or null the state will be applied to all drop frames entries.\n\nx-constraint:\n- ../chaos/chaos.yaml/components/schemas/DropFrames/properties/name\n'
  _STATEREQUESTCHAOSDROPFRAMES.fields_by_name['state']._options = None
  _STATEREQUESTCHAOSDROPFRAMES.fields_by_name['state']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _STATEREQUESTCHAOSDROPFRAMES._options = None
  _STATEREQUESTCHAOSDROPFRAMES._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _STATERESPONSE.fields_by_name['chaos']._options = None
  _STATERESPONSE.fields_by_name['chaos']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _STATERESPONSE._options = None
  _STATERESPONSE._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _STATERESPONSECHAOS.fields_by_name['drop_frames']._options = None
  _STATERESPONSECHAOS.fields_by_name['drop_frames']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _STATERESPONSECHAOS.fields_by_name['background_traffic']._options = None
  _STATERESPONSECHAOS.fields_by_name['background_traffic']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _STATERESPONSECHAOS._options = None
  _STATERESPONSECHAOS._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _STATERESPONSECHAOSBACKGROUNDTRAFFIC.fields_by_name['started']._options = None
  _STATERESPONSECHAOSBACKGROUNDTRAFFIC.fields_by_name['started']._serialized_options = b'\222\246\035}\242\001zThe names of the started flows.\n\nx-constraint:\n- ../chaos/background_traffic.yaml/components/schemas/Flow/properties/name\n'
  _STATERESPONSECHAOSBACKGROUNDTRAFFIC.fields_by_name['stopped']._options = None
  _STATERESPONSECHAOSBACKGROUNDTRAFFIC.fields_by_name['stopped']._serialized_options = b'\222\246\035}\242\001zThe names of the stopped flows.\n\nx-constraint:\n- ../chaos/background_traffic.yaml/components/schemas/Flow/properties/name\n'
  _STATERESPONSECHAOSBACKGROUNDTRAFFIC._options = None
  _STATERESPONSECHAOSBACKGROUNDTRAFFIC._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _STATERESPONSECHAOSDROPFRAMES.fields_by_name['started']._options = None
  _STATERESPONSECHAOSDROPFRAMES.fields_by_name['started']._serialized_options = b'\222\246\035\211\001\242\001\205\001The names of the started drop frames experiments.\n\nx-constraint:\n- ../chaos/chaos.yaml/components/schemas/DropFrames/properties/name\n'
  _STATERESPONSECHAOSDROPFRAMES.fields_by_name['stopped']._options = None
  _STATERESPONSECHAOSDROPFRAMES.fields_by_name['stopped']._serialized_options = b'\222\246\035\211\001\242\001\205\001The names of the stopped drop frames experiments.\n\nx-constraint:\n- ../chaos/chaos.yaml/components/schemas/DropFrames/properties/name\n'
  _STATERESPONSECHAOSDROPFRAMES._options = None
  _STATERESPONSECHAOSDROPFRAMES._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _OPENAPI._options = None
  _OPENAPI._serialized_options = b'\232\246\035\037R\035Description missing in models'
  _OPENAPI.methods_by_name['SetConfig']._options = None
  _OPENAPI.methods_by_name['SetConfig']._serialized_options = b'\242\246\035%R#Sets the ONEx fabric configuration.'
  _OPENAPI.methods_by_name['GetConfig']._options = None
  _OPENAPI.methods_by_name['GetConfig']._serialized_options = b'\242\246\035%R#Gets the ONEx fabric configuration.'
  _OPENAPI.methods_by_name['SetState']._options = None
  _OPENAPI.methods_by_name['SetState']._serialized_options = b'\242\246\0355R3Updates the state of ONEx configured experiment(s).'
  _OPENAPI.methods_by_name['GetState']._options = None
  _OPENAPI.methods_by_name['GetState']._serialized_options = b'\242\246\0350R.Gets the state of ONEx configured experiments.'
  _OPENAPIMSGOPT._serialized_start=101
  _OPENAPIMSGOPT._serialized_end=137
  _OPENAPIFLDOPT._serialized_start=139
  _OPENAPIFLDOPT._serialized_end=192
  _OPENAPISVCOPT._serialized_start=194
  _OPENAPISVCOPT._serialized_end=230
  _OPENAPIRPCOPT._serialized_start=232
  _OPENAPIRPCOPT._serialized_end=268
  _GLOBALNAMEDOBJECT._serialized_start=270
  _GLOBALNAMEDOBJECT._serialized_end=394
  _ERRORDETAILS._serialized_start=397
  _ERRORDETAILS._serialized_end=528
  _WARNINGDETAILS._serialized_start=531
  _WARNINGDETAILS._serialized_end=666
  _ERRORITEM._serialized_start=669
  _ERRORITEM._serialized_end=925
  _CONFIG._serialized_start=928
  _CONFIG._serialized_end=1432
  _HOST._serialized_start=1435
  _HOST._serialized_end=1902
  _FABRIC._serialized_start=1905
  _FABRIC._serialized_end=2300
  _FABRIC_CHOICE._serialized_start=2200
  _FABRIC_CHOICE._serialized_end=2243
  _FABRIC_CHOICE_ENUM._serialized_start=2210
  _FABRIC_CHOICE_ENUM._serialized_end=2243
  _FABRICCLOS._serialized_start=2303
  _FABRICCLOS._serialized_end=3088
  _FABRICSPINE._serialized_start=3091
  _FABRICSPINE._serialized_end=3961
  _FABRICSPINE_DOWNLINKECMPMODE._serialized_start=3773
  _FABRICSPINE_DOWNLINKECMPMODE._serialized_end=3870
  _FABRICSPINE_DOWNLINKECMPMODE_ENUM._serialized_start=3793
  _FABRICSPINE_DOWNLINKECMPMODE_ENUM._serialized_end=3870
  _FABRICPOD._serialized_start=3964
  _FABRICPOD._serialized_end=4280
  _FABRICPODPROFILE._serialized_start=4283
  _FABRICPODPROFILE._serialized_end=4715
  _FABRICPODSWITCH._serialized_start=4718
  _FABRICPODSWITCH._serialized_end=6001
  _FABRICPODSWITCH_UPLINKECMPMODE._serialized_start=5695
  _FABRICPODSWITCH_UPLINKECMPMODE._serialized_end=5790
  _FABRICPODSWITCH_UPLINKECMPMODE_ENUM._serialized_start=3793
  _FABRICPODSWITCH_UPLINKECMPMODE_ENUM._serialized_end=3870
  _FABRICPODSWITCH_DOWNLINKECMPMODE._serialized_start=3773
  _FABRICPODSWITCH_DOWNLINKECMPMODE._serialized_end=3870
  _FABRICPODSWITCH_DOWNLINKECMPMODE_ENUM._serialized_start=3793
  _FABRICPODSWITCH_DOWNLINKECMPMODE_ENUM._serialized_end=3870
  _FABRICTOR._serialized_start=6004
  _FABRICTOR._serialized_end=6343
  _FABRICTORPROFILE._serialized_start=6346
  _FABRICTORPROFILE._serialized_end=7459
  _FABRICTORPROFILE_TORMODE._serialized_start=7171
  _FABRICTORPROFILE_TORMODE._serialized_end=7229
  _FABRICTORPROFILE_TORMODE_ENUM._serialized_start=7182
  _FABRICTORPROFILE_TORMODE_ENUM._serialized_end=7229
  _FABRICTORPROFILE_UPLINKECMPMODE._serialized_start=5695
  _FABRICTORPROFILE_UPLINKECMPMODE._serialized_end=5790
  _FABRICTORPROFILE_UPLINKECMPMODE_ENUM._serialized_start=3793
  _FABRICTORPROFILE_UPLINKECMPMODE_ENUM._serialized_end=3870
  _FABRICTORPROFILEOVERSUBSCRIPTION._serialized_start=7462
  _FABRICTORPROFILEOVERSUBSCRIPTION._serialized_end=7947
  _FABRICTORPROFILEOVERSUBSCRIPTION_MODE._serialized_start=7779
  _FABRICTORPROFILEOVERSUBSCRIPTION_MODE._serialized_end=7860
  _FABRICTORPROFILEOVERSUBSCRIPTION_MODE_ENUM._serialized_start=7787
  _FABRICTORPROFILEOVERSUBSCRIPTION_MODE_ENUM._serialized_end=7860
  _FABRICQOSPROFILE._serialized_start=7950
  _FABRICQOSPROFILE._serialized_end=8572
  _FABRICQOSPROFILEINGRESSADMISSION._serialized_start=8575
  _FABRICQOSPROFILEINGRESSADMISSION._serialized_end=9023
  _FABRICQOSPROFILESCHEDULER._serialized_start=9026
  _FABRICQOSPROFILESCHEDULER._serialized_end=9430
  _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE._serialized_start=9287
  _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE._serialized_end=9374
  _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE_ENUM._serialized_start=9304
  _FABRICQOSPROFILESCHEDULER_SCHEDULERMODE_ENUM._serialized_end=9374
  _FABRICQOSPROFILEPACKETCLASSIFICATION._serialized_start=9433
  _FABRICQOSPROFILEPACKETCLASSIFICATION._serialized_end=9840
  _FABRICQOSPROFILEPACKETCLASSIFICATIONMAP._serialized_start=9842
  _FABRICQOSPROFILEPACKETCLASSIFICATIONMAP._serialized_end=9920
  _FABRICQOSPROFILEWRED._serialized_start=9923
  _FABRICQOSPROFILEWRED._serialized_end=10607
  _SWITCHHOSTLINK._serialized_start=10610
  _SWITCHHOSTLINK._serialized_end=11964
  _SWITCHHOSTLINK_HOSTTYPE._serialized_start=11667
  _SWITCHHOSTLINK_HOSTTYPE._serialized_end=11743
  _SWITCHHOSTLINK_HOSTTYPE_ENUM._serialized_start=11679
  _SWITCHHOSTLINK_HOSTTYPE_ENUM._serialized_end=11743
  _SWITCHHOSTLINK_CHOICE._serialized_start=11745
  _SWITCHHOSTLINK_CHOICE._serialized_end=11807
  _SWITCHHOSTLINK_CHOICE_ENUM._serialized_start=11755
  _SWITCHHOSTLINK_CHOICE_ENUM._serialized_end=11807
  _SWITCHHOSTLINKSWITCHREF._serialized_start=11967
  _SWITCHHOSTLINKSWITCHREF._serialized_end=12295
  _L1SETTINGSPROFILE._serialized_start=12298
  _L1SETTINGSPROFILE._serialized_end=13142
  _L1SETTINGSPROFILE_LINKSPEED._serialized_start=12876
  _L1SETTINGSPROFILE_LINKSPEED._serialized_end=12971
  _L1SETTINGSPROFILE_LINKSPEED_ENUM._serialized_start=12889
  _L1SETTINGSPROFILE_LINKSPEED_ENUM._serialized_end=12971
  _L1SETTINGSPROFILE_CHOICE._serialized_start=12973
  _L1SETTINGSPROFILE_CHOICE._serialized_end=13039
  _L1SETTINGSPROFILE_CHOICE_ENUM._serialized_start=12983
  _L1SETTINGSPROFILE_CHOICE_ENUM._serialized_end=13039
  _L1SETTINGSPROFILEAUTONEGOTIATION._serialized_start=13145
  _L1SETTINGSPROFILEAUTONEGOTIATION._serialized_end=13310
  _L1SETTINGSPROFILEMANUAL._serialized_start=13313
  _L1SETTINGSPROFILEMANUAL._serialized_end=13611
  _L1SETTINGSPROFILEMANUAL_FECMODE._serialized_start=13486
  _L1SETTINGSPROFILEMANUAL_FECMODE._serialized_end=13561
  _L1SETTINGSPROFILEMANUAL_FECMODE_ENUM._serialized_start=13497
  _L1SETTINGSPROFILEMANUAL_FECMODE_ENUM._serialized_end=13561
  _CHAOS._serialized_start=13614
  _CHAOS._serialized_end=13887
  _CHAOSDROPFRAMES._serialized_start=13890
  _CHAOSDROPFRAMES._serialized_end=14639
  _CHAOSDROPFRAMES_MODE._serialized_start=14425
  _CHAOSDROPFRAMES_MODE._serialized_end=14491
  _CHAOSDROPFRAMES_MODE_ENUM._serialized_start=14433
  _CHAOSDROPFRAMES_MODE_ENUM._serialized_end=14491
  _CHAOSBACKGROUNDTRAFFIC._serialized_start=14642
  _CHAOSBACKGROUNDTRAFFIC._serialized_end=14799
  _CHAOSBACKGROUNDTRAFFICFLOW._serialized_start=14802
  _CHAOSBACKGROUNDTRAFFICFLOW._serialized_end=15339
  _CHAOSBACKGROUNDTRAFFICFLOW_CHOICE._serialized_start=15201
  _CHAOSBACKGROUNDTRAFFICFLOW_CHOICE._serialized_end=15249
  _CHAOSBACKGROUNDTRAFFICFLOW_CHOICE_ENUM._serialized_start=15211
  _CHAOSBACKGROUNDTRAFFICFLOW_CHOICE_ENUM._serialized_end=15249
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS._serialized_start=15342
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS._serialized_end=16054
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS_TRANSMISSIONMODE._serialized_start=15895
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS_TRANSMISSIONMODE._serialized_end=15965
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS_TRANSMISSIONMODE_ENUM._serialized_start=15915
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESS_TRANSMISSIONMODE_ENUM._serialized_end=15965
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET._serialized_start=16057
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET._serialized_end=16843
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET_L4PROTOCOL._serialized_start=16655
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET_L4PROTOCOL._serialized_end=16710
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET_L4PROTOCOL_ENUM._serialized_start=16669
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKET_L4PROTOCOL_ENUM._serialized_end=16710
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD._serialized_start=16846
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSPACKETDSFIELD._serialized_end=17112
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST._serialized_start=17115
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST._serialized_end=17561
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST_UNIT._serialized_start=17437
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST_UNIT._serialized_end=17476
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST_UNIT_ENUM._serialized_start=17445
  _CHAOSBACKGROUNDTRAFFICFLOWSTATELESSBURST_UNIT_ENUM._serialized_end=17476
  _INSIGHTS._serialized_start=17564
  _INSIGHTS._serialized_end=17725
  _INSIGHTSPORTMIRRORING._serialized_start=17728
  _INSIGHTSPORTMIRRORING._serialized_end=18304
  _INSIGHTSPORTMIRRORING_MIRRORTYPE._serialized_start=18175
  _INSIGHTSPORTMIRRORING_MIRRORTYPE._serialized_end=18251
  _INSIGHTSPORTMIRRORING_MIRRORTYPE_ENUM._serialized_start=18189
  _INSIGHTSPORTMIRRORING_MIRRORTYPE_ENUM._serialized_end=18251
  _STATEREQUEST._serialized_start=18307
  _STATEREQUEST._serialized_end=18460
  _STATEREQUESTCHAOS._serialized_start=18463
  _STATEREQUESTCHAOS._serialized_end=18788
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC._serialized_start=18791
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC._serialized_end=19338
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC_STATE._serialized_start=19233
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC_STATE._serialized_end=19291
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC_STATE_ENUM._serialized_start=19242
  _STATEREQUESTCHAOSBACKGROUNDTRAFFIC_STATE_ENUM._serialized_end=19291
  _STATEREQUESTCHAOSDROPFRAMES._serialized_start=19341
  _STATEREQUESTCHAOSDROPFRAMES._serialized_end=19875
  _STATEREQUESTCHAOSDROPFRAMES_STATE._serialized_start=19233
  _STATEREQUESTCHAOSDROPFRAMES_STATE._serialized_end=19291
  _STATEREQUESTCHAOSDROPFRAMES_STATE_ENUM._serialized_start=19242
  _STATEREQUESTCHAOSDROPFRAMES_STATE_ENUM._serialized_end=19291
  _STATERESPONSE._serialized_start=19878
  _STATERESPONSE._serialized_end=20033
  _STATERESPONSECHAOS._serialized_start=20036
  _STATERESPONSECHAOS._serialized_end=20364
  _STATERESPONSECHAOSBACKGROUNDTRAFFIC._serialized_start=20367
  _STATERESPONSECHAOSBACKGROUNDTRAFFIC._serialized_end=20741
  _STATERESPONSECHAOSDROPFRAMES._serialized_start=20744
  _STATERESPONSECHAOSDROPFRAMES._serialized_end=21137
  _SETCONFIGREQUEST._serialized_start=21139
  _SETCONFIGREQUEST._serialized_end=21196
  _SETCONFIGRESPONSE._serialized_start=21199
  _SETCONFIGRESPONSE._serialized_end=21457
  _GETCONFIGRESPONSE._serialized_start=21460
  _GETCONFIGRESPONSE._serialized_end=21710
  _SETSTATEREQUEST._serialized_start=21712
  _SETSTATEREQUEST._serialized_end=21781
  _SETSTATERESPONSE._serialized_start=21784
  _SETSTATERESPONSE._serialized_end=22041
  _GETSTATERESPONSE._serialized_start=22044
  _GETSTATERESPONSE._serialized_end=22300
  _OPENAPI._serialized_start=22303
  _OPENAPI._serialized_end=22846
# @@protoc_insertion_point(module_scope)
